from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from datetime import date, datetime


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class CreativeWorkSeason(CreativeWork):
    """A media season, e.g. TV, radio, video game etc.

    See: https://schema.org/CreativeWorkSeason
    Model depth: 3
    """

    type_: str = Field(default="CreativeWorkSeason", alias="@type", const=True)
    trailer: Optional[Union[List[Union["VideoObject", str]], "VideoObject", str]] = (
        Field(
            default=None,
            description="The trailer of a movie or TV/radio series, season, episode, etc.",
        )
    )
    episode: Optional[Union[List[Union["Episode", str]], "Episode", str]] = Field(
        default=None,
        description="An episode of a TV, radio or game media within a series or season.",
    )
    numberOfEpisodes: Optional[
        Union[List[Union[int, "Integer", str]], int, "Integer", str]
    ] = Field(
        default=None,
        description="The number of episodes in this season or series.",
    )
    endDate: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The end date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601)).",
    )
    productionCompany: Optional[
        Union[List[Union["Organization", str]], "Organization", str]
    ] = Field(
        default=None,
        description="The production company or studio responsible for the item, e.g. series, video game, episode etc.",
    )
    director: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="A director of e.g. TV, radio, movie, video gaming etc. content, or of an event. Directors can be associated with individual items or with a series, episode, clip.",
    )
    episodes: Optional[Union[List[Union["Episode", str]], "Episode", str]] = Field(
        default=None,
        description="An episode of a TV/radio series or season.",
    )
    actor: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="An actor, e.g. in TV, radio, movie, video games etc., or in an event. Actors can be associated with individual items or with a series, episode, clip.",
    )
    partOfSeries: Optional[
        Union[List[Union["CreativeWorkSeries", str]], "CreativeWorkSeries", str]
    ] = Field(
        default=None,
        description="The series to which this episode or season belongs.",
    )
    startDate: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The start date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601)).",
    )
    seasonNumber: Optional[
        Union[List[Union[int, "Integer", str, "Text"]], int, "Integer", str, "Text"]
    ] = Field(
        default=None,
        description="Position of the season within an ordered group of seasons.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.VideoObject import VideoObject
    from pydantic2_schemaorg.Episode import Episode
    from pydantic2_schemaorg.Integer import Integer
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.CreativeWorkSeries import CreativeWorkSeries
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.EventStatusType import EventStatusType


class EventPostponed(EventStatusType):
    """The event has been postponed and no new date has been set. The event's previousStartDate should be set.

    See: https://schema.org/EventPostponed
    Model depth: 6
    """

    type_: str = Field(default="EventPostponed", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.FindAction import FindAction


class DiscoverAction(FindAction):
    """The act of discovering/finding an object.

    See: https://schema.org/DiscoverAction
    Model depth: 4
    """

    type_: str = Field(default="DiscoverAction", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PaymentStatusType import PaymentStatusType


class PaymentAutomaticallyApplied(PaymentStatusType):
    """An automatic payment system is in place and will be used.

    See: https://schema.org/PaymentAutomaticallyApplied
    Model depth: 6
    """

    type_: str = Field(default="PaymentAutomaticallyApplied", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import StrictBool
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MediaObject import MediaObject


class ImageObject(MediaObject):
    """An image file.

    See: https://schema.org/ImageObject
    Model depth: 4
    """

    type_: str = Field(default="ImageObject", alias="@type", const=True)
    representativeOfPage: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="Indicates whether this image is representative of the content of the page.",
    )
    exifData: Optional[
        Union[List[Union[str, "Text", "PropertyValue"]], str, "Text", "PropertyValue"]
    ] = Field(
        default=None,
        description="exif data for this object.",
    )
    embeddedTextCaption: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Represents textual captioning from a [[MediaObject]], e.g. text of a 'meme'.",
    )
    caption: Optional[
        Union[List[Union[str, "Text", "MediaObject"]], str, "Text", "MediaObject"]
    ] = Field(
        default=None,
        description="The caption for this object. For downloadable machine formats (closed caption, subtitles etc.) use MediaObject and indicate the [[encodingFormat]].",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Boolean import Boolean
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.PropertyValue import PropertyValue
    from pydantic2_schemaorg.MediaObject import MediaObject



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class MemberProgramTier(Intangible):
    """A MemberProgramTier specifies a tier under a loyalty (member) program, for example \"gold\".

    See: https://schema.org/MemberProgramTier
    Model depth: 3
    """

    type_: str = Field(default="MemberProgramTier", alias="@type", const=True)
    hasTierBenefit: Optional[
        Union[List[Union["TierBenefitEnumeration", str]], "TierBenefitEnumeration", str]
    ] = Field(
        default=None,
        description="A member benefit for a particular tier of a loyalty program.",
    )
    membershipPointsEarned: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "QuantitativeValue", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The number of membership points earned by the member. If necessary, the unitText can be used to express the units the points are issued in. (E.g. stars, miles, etc.)",
    )
    isTierOf: Optional[
        Union[List[Union["MemberProgram", str]], "MemberProgram", str]
    ] = Field(
        default=None,
        description="The member program this tier is a part of.",
    )
    hasTierRequirement: Optional[
        Union[
            List[
                Union[
                    str,
                    "Text",
                    "MonetaryAmount",
                    "CreditCard",
                    "UnitPriceSpecification",
                ]
            ],
            str,
            "Text",
            "MonetaryAmount",
            "CreditCard",
            "UnitPriceSpecification",
        ]
    ] = Field(
        default=None,
        description="A requirement for a user to join a membership tier, for example: a CreditCard if the tier requires sign up for a credit card, A UnitPriceSpecification if the user is required to pay a (periodic) fee, or a MonetaryAmount if the user needs to spend a minimum amount to join the tier. If a tier is free to join then this property does not need to be specified.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.TierBenefitEnumeration import TierBenefitEnumeration
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.MemberProgram import MemberProgram
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.MonetaryAmount import MonetaryAmount
    from pydantic2_schemaorg.CreditCard import CreditCard
    from pydantic2_schemaorg.UnitPriceSpecification import UnitPriceSpecification



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreateAction import CreateAction


class WriteAction(CreateAction):
    """The act of authoring written creative content.

    See: https://schema.org/WriteAction
    Model depth: 4
    """

    type_: str = Field(default="WriteAction", alias="@type", const=True)
    inLanguage: Optional[
        Union[List[Union[str, "Text", "Language"]], str, "Text", "Language"]
    ] = Field(
        default=None,
        description="The language of the content or performance or used in an action. Please use one of the language codes from the [IETF BCP 47 standard](http://tools.ietf.org/html/bcp47). See also [[availableLanguage]].",
    )
    language: Optional[Union[List[Union["Language", str]], "Language", str]] = Field(
        default=None,
        description="A sub property of instrument. The language used on this action.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Language import Language



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.WebPage import WebPage


class MedicalWebPage(WebPage):
    """A web page that provides medical information.

    See: https://schema.org/MedicalWebPage
    Model depth: 4
    """

    type_: str = Field(default="MedicalWebPage", alias="@type", const=True)
    medicalAudience: Optional[
        Union[
            List[Union["MedicalAudience", "MedicalAudienceType", str]],
            "MedicalAudience",
            "MedicalAudienceType",
            str,
        ]
    ] = Field(
        default=None,
        description="Medical audience for page.",
    )
    aspect: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="An aspect of medical practice that is considered on the page, such as 'diagnosis', 'treatment', 'causes', 'prognosis', 'etiology', 'epidemiology', etc.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MedicalAudience import MedicalAudience
    from pydantic2_schemaorg.MedicalAudienceType import MedicalAudienceType
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.InteractAction import InteractAction


class CommunicateAction(InteractAction):
    """The act of conveying information to another person via a communication medium (instrument) such as speech,
     email, or telephone conversation.

    See: https://schema.org/CommunicateAction
    Model depth: 4
    """

    type_: str = Field(default="CommunicateAction", alias="@type", const=True)
    recipient: Optional[
        Union[
            List[Union["Organization", "Audience", "Person", "ContactPoint", str]],
            "Organization",
            "Audience",
            "Person",
            "ContactPoint",
            str,
        ]
    ] = Field(
        default=None,
        description="A sub property of participant. The participant who is at the receiving end of the action.",
    )
    inLanguage: Optional[
        Union[List[Union[str, "Text", "Language"]], str, "Text", "Language"]
    ] = Field(
        default=None,
        description="The language of the content or performance or used in an action. Please use one of the language codes from the [IETF BCP 47 standard](http://tools.ietf.org/html/bcp47). See also [[availableLanguage]].",
    )
    about: Optional[Union[List[Union["Thing", str]], "Thing", str]] = Field(
        default=None,
        description="The subject matter of the content.",
    )
    language: Optional[Union[List[Union["Language", str]], "Language", str]] = Field(
        default=None,
        description="A sub property of instrument. The language used on this action.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Audience import Audience
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.ContactPoint import ContactPoint
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Language import Language
    from pydantic2_schemaorg.Thing import Thing



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class DigitalDocumentPermission(Intangible):
    """A permission for a particular person or group to access a particular file.

    See: https://schema.org/DigitalDocumentPermission
    Model depth: 3
    """

    type_: str = Field(default="DigitalDocumentPermission", alias="@type", const=True)
    permissionType: Optional[
        Union[
            List[Union["DigitalDocumentPermissionType", str]],
            "DigitalDocumentPermissionType",
            str,
        ]
    ] = Field(
        default=None,
        description="The type of permission granted the person, organization, or audience.",
    )
    grantee: Optional[
        Union[
            List[Union["ContactPoint", "Audience", "Person", "Organization", str]],
            "ContactPoint",
            "Audience",
            "Person",
            "Organization",
            str,
        ]
    ] = Field(
        default=None,
        description="The person, organization, contact point, or audience that has been granted this permission.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.DigitalDocumentPermissionType import (
        DigitalDocumentPermissionType,
    )
    from pydantic2_schemaorg.ContactPoint import ContactPoint
    from pydantic2_schemaorg.Audience import Audience
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class Brand(Intangible):
    """A brand is a name used by an organization or business person for labeling a product, product group, or similar.

    See: https://schema.org/Brand
    Model depth: 3
    """

    type_: str = Field(default="Brand", alias="@type", const=True)
    logo: Optional[
        Union[
            List[Union[AnyUrl, "URL", "ImageObject", str]],
            AnyUrl,
            "URL",
            "ImageObject",
            str,
        ]
    ] = Field(
        default=None,
        description="An associated logo.",
    )
    aggregateRating: Optional[
        Union[List[Union["AggregateRating", str]], "AggregateRating", str]
    ] = Field(
        default=None,
        description="The overall rating, based on a collection of reviews or ratings, of the item.",
    )
    slogan: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A slogan or motto associated with the item.",
    )
    review: Optional[Union[List[Union["Review", str]], "Review", str]] = Field(
        default=None,
        description="A review of the item.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.ImageObject import ImageObject
    from pydantic2_schemaorg.AggregateRating import AggregateRating
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Review import Review



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.EventAttendanceModeEnumeration import (
    EventAttendanceModeEnumeration,
)


class OnlineEventAttendanceMode(EventAttendanceModeEnumeration):
    """OnlineEventAttendanceMode - an event that is primarily conducted online.

    See: https://schema.org/OnlineEventAttendanceMode
    Model depth: 5
    """

    type_: str = Field(default="OnlineEventAttendanceMode", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.House import House


class SingleFamilyResidence(House):
    """Residence type: Single-family home.

    See: https://schema.org/SingleFamilyResidence
    Model depth: 5
    """

    type_: str = Field(default="SingleFamilyResidence", alias="@type", const=True)
    occupancy: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The allowed total occupancy for the accommodation in persons (including infants etc). For individual accommodations, this is not necessarily the legal maximum but defines the permitted usage as per the contractual agreement (e.g. a double room used by a single person). Typical unit code(s): C62 for person.",
    )
    numberOfRooms: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "QuantitativeValue", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The number of rooms (excluding bathrooms and closets) of the accommodation or lodging business. Typical unit code(s): ROM for room or C62 for no unit. The type of room can be put in the unitText property of the QuantitativeValue.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.Number import Number



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class SheetMusic(CreativeWork):
    """Printed music, as opposed to performed or recorded music.

    See: https://schema.org/SheetMusic
    Model depth: 3
    """

    type_: str = Field(default="SheetMusic", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import StrictBool


from pydantic.v1 import Field
from pydantic2_schemaorg.PublicationEvent import PublicationEvent


class BroadcastEvent(PublicationEvent):
    """An over the air or online broadcast event.

    See: https://schema.org/BroadcastEvent
    Model depth: 4
    """

    type_: str = Field(default="BroadcastEvent", alias="@type", const=True)
    broadcastOfEvent: Optional[Union[List[Union["Event", str]], "Event", str]] = Field(
        default=None,
        description="The event being broadcast such as a sporting event or awards ceremony.",
    )
    videoFormat: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The type of screening or video broadcast used (e.g. IMAX, 3D, SD, HD, etc.).",
    )
    isLiveBroadcast: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="True if the broadcast is of a live event.",
    )
    subtitleLanguage: Optional[
        Union[List[Union[str, "Text", "Language"]], str, "Text", "Language"]
    ] = Field(
        default=None,
        description="Languages in which subtitles/captions are available, in [IETF BCP 47 standard format](http://tools.ietf.org/html/bcp47).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Event import Event
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Boolean import Boolean
    from pydantic2_schemaorg.Language import Language



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CriticReview import CriticReview
from pydantic2_schemaorg.NewsArticle import NewsArticle


class ReviewNewsArticle(CriticReview, NewsArticle):
    """A [[NewsArticle]] and [[CriticReview]] providing a professional critic's assessment of a service, product,
     performance, or artistic or literary work.

    See: https://schema.org/ReviewNewsArticle
    Model depth: 5
    """

    type_: str = Field(default="ReviewNewsArticle", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalEnumeration import MedicalEnumeration


class MedicalDevicePurpose(MedicalEnumeration):
    """Categories of medical devices, organized by the purpose or intended use of the device.

    See: https://schema.org/MedicalDevicePurpose
    Model depth: 5
    """

    type_: str = Field(default="MedicalDevicePurpose", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Store import Store


class MusicStore(Store):
    """A music store.

    See: https://schema.org/MusicStore
    Model depth: 5
    """

    type_: str = Field(default="MusicStore", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.InfectiousAgentClass import InfectiousAgentClass


class Fungus(InfectiousAgentClass):
    """Pathogenic fungus.

    See: https://schema.org/Fungus
    Model depth: 6
    """

    type_: str = Field(default="Fungus", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ReturnLabelSourceEnumeration import (
    ReturnLabelSourceEnumeration,
)


class ReturnLabelDownloadAndPrint(ReturnLabelSourceEnumeration):
    """Indicated that a return label must be downloaded and printed by the customer.

    See: https://schema.org/ReturnLabelDownloadAndPrint
    Model depth: 5
    """

    type_: str = Field(default="ReturnLabelDownloadAndPrint", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class CarUsageType(Enumeration):
    """A value indicating a special usage of a car, e.g. commercial rental, driving school, or as a taxi.

    See: https://schema.org/CarUsageType
    Model depth: 4
    """

    type_: str = Field(default="CarUsageType", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.StructuredValue import StructuredValue


class DefinedRegion(StructuredValue):
    """A DefinedRegion is a geographic area defined by potentially arbitrary (rather than political, administrative
     or natural geographical) criteria. Properties are provided for defining a region by reference to sets of
     postal codes. Examples: a delivery destination when shopping. Region where regional pricing is configured.
     Requirement 1: Country: US States: \"NY\", \"CA\" Requirement 2: Country: US PostalCode Set: { [94000-94585],
     [97000, 97999], [13000, 13599]} { [12345, 12345], [78945, 78945], } Region = state, canton, prefecture,
     autonomous community...

    See: https://schema.org/DefinedRegion
    Model depth: 4
    """

    type_: str = Field(default="DefinedRegion", alias="@type", const=True)
    addressCountry: Optional[
        Union[List[Union[str, "Text", "Country"]], str, "Text", "Country"]
    ] = Field(
        default=None,
        description="The country. For example, USA. You can also provide the two-letter [ISO 3166-1 alpha-2 country code](http://en.wikipedia.org/wiki/ISO_3166-1).",
    )
    postalCode: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The postal code. For example, 94043.",
    )
    postalCodeRange: Optional[
        Union[
            List[Union["PostalCodeRangeSpecification", str]],
            "PostalCodeRangeSpecification",
            str,
        ]
    ] = Field(
        default=None,
        description="A defined range of postal codes.",
    )
    postalCodePrefix: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A defined range of postal codes indicated by a common textual prefix. Used for non-numeric systems such as UK.",
    )
    addressRegion: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The region in which the locality is, and which is in the country. For example, California or another appropriate first-level [Administrative division](https://en.wikipedia.org/wiki/List_of_administrative_divisions_by_country).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Country import Country
    from pydantic2_schemaorg.PostalCodeRangeSpecification import (
        PostalCodeRangeSpecification,
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PaymentMethodType import PaymentMethodType


class InStorePrepay(PaymentMethodType):
    """Payment in advance in some form of shop or kiosk for goods purchased online.

    See: https://schema.org/InStorePrepay
    Model depth: 5
    """

    type_: str = Field(default="InStorePrepay", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import AnyUrl
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Organization import Organization


class NewsMediaOrganization(Organization):
    """A News/Media organization such as a newspaper or TV station.

    See: https://schema.org/NewsMediaOrganization
    Model depth: 3
    """

    type_: str = Field(default="NewsMediaOrganization", alias="@type", const=True)
    ethicsPolicy: Optional[
        Union[
            List[Union[AnyUrl, "URL", "CreativeWork", str]],
            AnyUrl,
            "URL",
            "CreativeWork",
            str,
        ]
    ] = Field(
        default=None,
        description="Statement about ethics policy, e.g. of a [[NewsMediaOrganization]] regarding journalistic and publishing practices, or of a [[Restaurant]], a page describing food source policies. In the case of a [[NewsMediaOrganization]], an ethicsPolicy is typically a statement describing the personal, organizational, and corporate standards of behavior expected by the organization.",
    )
    unnamedSourcesPolicy: Optional[
        Union[
            List[Union[AnyUrl, "URL", "CreativeWork", str]],
            AnyUrl,
            "URL",
            "CreativeWork",
            str,
        ]
    ] = Field(
        default=None,
        description="For an [[Organization]] (typically a [[NewsMediaOrganization]]), a statement about policy on use of unnamed sources and the decision process required.",
    )
    masthead: Optional[
        Union[
            List[Union[AnyUrl, "URL", "CreativeWork", str]],
            AnyUrl,
            "URL",
            "CreativeWork",
            str,
        ]
    ] = Field(
        default=None,
        description="For a [[NewsMediaOrganization]], a link to the masthead page or a page listing top editorial management.",
    )
    verificationFactCheckingPolicy: Optional[
        Union[
            List[Union[AnyUrl, "URL", "CreativeWork", str]],
            AnyUrl,
            "URL",
            "CreativeWork",
            str,
        ]
    ] = Field(
        default=None,
        description="Disclosure about verification and fact-checking processes for a [[NewsMediaOrganization]] or other fact-checking [[Organization]].",
    )
    diversityStaffingReport: Optional[
        Union[List[Union[AnyUrl, "URL", "Article", str]], AnyUrl, "URL", "Article", str]
    ] = Field(
        default=None,
        description="For an [[Organization]] (often but not necessarily a [[NewsMediaOrganization]]), a report on staffing diversity issues. In a news context this might be for example ASNE or RTDNA (US) reports, or self-reported.",
    )
    ownershipFundingInfo: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", "AboutPage", "CreativeWork"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            "AboutPage",
            "CreativeWork",
        ]
    ] = Field(
        default=None,
        description="For an [[Organization]] (often but not necessarily a [[NewsMediaOrganization]]), a description of organizational ownership structure; funding and grants. In a news/media setting, this is with particular reference to editorial independence. Note that the [[funder]] is also available and can be used to make basic funder information machine-readable.",
    )
    noBylinesPolicy: Optional[
        Union[
            List[Union[AnyUrl, "URL", "CreativeWork", str]],
            AnyUrl,
            "URL",
            "CreativeWork",
            str,
        ]
    ] = Field(
        default=None,
        description="For a [[NewsMediaOrganization]] or other news-related [[Organization]], a statement explaining when authors of articles are not named in bylines.",
    )
    missionCoveragePrioritiesPolicy: Optional[
        Union[
            List[Union[AnyUrl, "URL", "CreativeWork", str]],
            AnyUrl,
            "URL",
            "CreativeWork",
            str,
        ]
    ] = Field(
        default=None,
        description="For a [[NewsMediaOrganization]], a statement on coverage priorities, including any public agenda or stance on issues.",
    )
    correctionsPolicy: Optional[
        Union[
            List[Union[AnyUrl, "URL", "CreativeWork", str]],
            AnyUrl,
            "URL",
            "CreativeWork",
            str,
        ]
    ] = Field(
        default=None,
        description="For an [[Organization]] (e.g. [[NewsMediaOrganization]]), a statement describing (in news media, the newsroom’s) disclosure and correction policy for errors.",
    )
    diversityPolicy: Optional[
        Union[
            List[Union[AnyUrl, "URL", "CreativeWork", str]],
            AnyUrl,
            "URL",
            "CreativeWork",
            str,
        ]
    ] = Field(
        default=None,
        description="Statement on diversity policy by an [[Organization]] e.g. a [[NewsMediaOrganization]]. For a [[NewsMediaOrganization]], a statement describing the newsroom’s diversity policy on both staffing and sources, typically providing staffing data.",
    )
    actionableFeedbackPolicy: Optional[
        Union[
            List[Union[AnyUrl, "URL", "CreativeWork", str]],
            AnyUrl,
            "URL",
            "CreativeWork",
            str,
        ]
    ] = Field(
        default=None,
        description="For a [[NewsMediaOrganization]] or other news-related [[Organization]], a statement about public engagement activities (for news media, the newsroom’s), including involving the public - digitally or otherwise -- in coverage decisions, reporting and activities after publication.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.CreativeWork import CreativeWork
    from pydantic2_schemaorg.Article import Article
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.AboutPage import AboutPage



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.AdultOrientedEnumeration import AdultOrientedEnumeration


class SexualContentConsideration(AdultOrientedEnumeration):
    """The item contains sexually oriented content such as nudity, suggestive or explicit material, or related
     online services, or is intended to enhance sexual activity. Examples: Erotic videos or magazine, sexual
     enhancement devices, sex toys.

    See: https://schema.org/SexualContentConsideration
    Model depth: 5
    """

    type_: str = Field(default="SexualContentConsideration", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty
from pydantic2_schemaorg.MedicalBusiness import MedicalBusiness


class DietNutrition(MedicalSpecialty, MedicalBusiness):
    """Dietetics and nutrition as a medical specialty.

    See: https://schema.org/DietNutrition
    Model depth: 5
    """

    type_: str = Field(default="DietNutrition", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalTherapy import MedicalTherapy


class OccupationalTherapy(MedicalTherapy):
    """A treatment of people with physical, emotional, or social problems, using purposeful activity to help them
     overcome or learn to deal with their problems.

    See: https://schema.org/OccupationalTherapy
    Model depth: 6
    """

    type_: str = Field(default="OccupationalTherapy", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Article import Article


class NewsArticle(Article):
    """A NewsArticle is an article whose content reports news, or provides background context and supporting materials
     for understanding the news. A more detailed overview of [schema.org News markup](/docs/news.html) is also
     available.

    See: https://schema.org/NewsArticle
    Model depth: 4
    """

    type_: str = Field(default="NewsArticle", alias="@type", const=True)
    printColumn: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The number of the column in which the NewsArticle appears in the print edition.",
    )
    printSection: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="If this NewsArticle appears in print, this field indicates the print section in which the article appeared.",
    )
    dateline: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description='A [dateline](https://en.wikipedia.org/wiki/Dateline) is a brief piece of text included in news articles that describes where and when the story was written or filed though the date is often omitted. Sometimes only a placename is provided. Structured representations of dateline-related information can also be expressed more explicitly using [[locationCreated]] (which represents where a work was created, e.g. where a news report was written). For location depicted or described in the content, use [[contentLocation]]. Dateline summaries are oriented more towards human readers than towards automated processing, and can vary substantially. Some examples: "BEIRUT, Lebanon, June 2.", "Paris, France", "December 19, 2017 11:43AM Reporting from Washington", "Beijing/Moscow", "QUEZON CITY, Philippines".',
    )
    printEdition: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The edition of the print product in which the NewsArticle appears.",
    )
    printPage: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="If this NewsArticle appears in print, this field indicates the name of the page on which the article is found. Please note that this field is intended for the exact page name (e.g. A5, B18).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.SportsOrganization import SportsOrganization


class SportsTeam(SportsOrganization):
    """Organization: Sports team.

    See: https://schema.org/SportsTeam
    Model depth: 4
    """

    type_: str = Field(default="SportsTeam", alias="@type", const=True)
    coach: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="A person that acts in a coaching role for a sports team.",
    )
    athlete: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="A person that acts as performing member of a sports team; a player as opposed to a coach.",
    )
    gender: Optional[
        Union[List[Union[str, "Text", "GenderType"]], str, "Text", "GenderType"]
    ] = Field(
        default=None,
        description='Gender of something, typically a [[Person]], but possibly also fictional characters, animals, etc. While https://schema.org/Male and https://schema.org/Female may be used, text strings are also acceptable for people who do not identify as a binary gender. The [[gender]] property can also be used in an extended sense to cover e.g. the gender of sports teams. As with the gender of individuals, we do not try to enumerate all possibilities. A mixed-gender [[SportsTeam]] can be indicated with a text value of "Mixed".',
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.GenderType import GenderType



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Periodical import Periodical


class Newspaper(Periodical):
    """A publication containing information about varied topics that are pertinent to general information, a geographic
     area, or a specific subject matter (i.e. business, culture, education). Often published daily.

    See: https://schema.org/Newspaper
    Model depth: 5
    """

    type_: str = Field(default="Newspaper", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalEvidenceLevel import MedicalEvidenceLevel


class EvidenceLevelA(MedicalEvidenceLevel):
    """Data derived from multiple randomized clinical trials or meta-analyses.

    See: https://schema.org/EvidenceLevelA
    Model depth: 6
    """

    type_: str = Field(default="EvidenceLevelA", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.TransferAction import TransferAction


class ReceiveAction(TransferAction):
    """The act of physically/electronically taking delivery of an object that has been transferred from an origin
     to a destination. Reciprocal of SendAction. Related actions: * [[SendAction]]: The reciprocal of ReceiveAction.
     * [[TakeAction]]: Unlike TakeAction, ReceiveAction does not imply that the ownership has been transferred
     (e.g. I can receive a package, but it does not mean the package is now mine).

    See: https://schema.org/ReceiveAction
    Model depth: 4
    """

    type_: str = Field(default="ReceiveAction", alias="@type", const=True)
    deliveryMethod: Optional[
        Union[List[Union["DeliveryMethod", str]], "DeliveryMethod", str]
    ] = Field(
        default=None,
        description="A sub property of instrument. The method of delivery.",
    )
    sender: Optional[
        Union[
            List[Union["Audience", "Person", "Organization", str]],
            "Audience",
            "Person",
            "Organization",
            str,
        ]
    ] = Field(
        default=None,
        description="A sub property of participant. The participant who is at the sending end of the action.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.DeliveryMethod import DeliveryMethod
    from pydantic2_schemaorg.Audience import Audience
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class Thesis(CreativeWork):
    """A thesis or dissertation document submitted in support of candidature for an academic degree or professional
     qualification.

    See: https://schema.org/Thesis
    Model depth: 3
    """

    type_: str = Field(default="Thesis", alias="@type", const=True)
    inSupportOf: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Qualification, candidature, degree, application that Thesis supports.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.HomeAndConstructionBusiness import HomeAndConstructionBusiness


class Plumber(HomeAndConstructionBusiness):
    """A plumbing service.

    See: https://schema.org/Plumber
    Model depth: 5
    """

    type_: str = Field(default="Plumber", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.RsvpResponseType import RsvpResponseType


class RsvpResponseYes(RsvpResponseType):
    """The invitee will attend.

    See: https://schema.org/RsvpResponseYes
    Model depth: 5
    """

    type_: str = Field(default="RsvpResponseYes", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import StrictInt, StrictFloat
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Action import Action


class SeekToAction(Action):
    """This is the [[Action]] of navigating to a specific [[startOffset]] timestamp within a [[VideoObject]],
     typically represented with a URL template structure.

    See: https://schema.org/SeekToAction
    Model depth: 3
    """

    type_: str = Field(default="SeekToAction", alias="@type", const=True)
    startOffset: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "HyperTocEntry", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "HyperTocEntry",
            str,
        ]
    ] = Field(
        default=None,
        description="The start time of the clip expressed as the number of seconds from the beginning of the work.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.HyperTocEntry import HyperTocEntry



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CommunicateAction import CommunicateAction


class ReplyAction(CommunicateAction):
    """The act of responding to a question/message asked/sent by the object. Related to [[AskAction]]. Related
     actions: * [[AskAction]]: Appears generally as an origin of a ReplyAction.

    See: https://schema.org/ReplyAction
    Model depth: 5
    """

    type_: str = Field(default="ReplyAction", alias="@type", const=True)
    resultComment: Optional[Union[List[Union["Comment", str]], "Comment", str]] = Field(
        default=None,
        description="A sub property of result. The Comment created or sent as a result of this action.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Comment import Comment



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from datetime import datetime, time


from pydantic.v1 import Field
from pydantic2_schemaorg.Reservation import Reservation


class LodgingReservation(Reservation):
    """A reservation for lodging at a hotel, motel, inn, etc. Note: This type is for information about actual reservations,
     e.g. in confirmation emails or HTML pages with individual confirmations of reservations.

    See: https://schema.org/LodgingReservation
    Model depth: 4
    """

    type_: str = Field(default="LodgingReservation", alias="@type", const=True)
    lodgingUnitType: Optional[
        Union[
            List[Union[str, "Text", "QualitativeValue"]],
            str,
            "Text",
            "QualitativeValue",
        ]
    ] = Field(
        default=None,
        description="Textual description of the unit type (including suite vs. room, size of bed, etc.).",
    )
    numChildren: Optional[
        Union[
            List[Union[int, "Integer", "QuantitativeValue", str]],
            int,
            "Integer",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The number of children staying in the unit.",
    )
    lodgingUnitDescription: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = (
        Field(
            default=None,
            description="A full description of the lodging unit.",
        )
    )
    checkoutTime: Optional[
        Union[
            List[Union[datetime, "DateTime", time, "Time", str]],
            datetime,
            "DateTime",
            time,
            "Time",
            str,
        ]
    ] = Field(
        default=None,
        description="The latest someone may check out of a lodging establishment.",
    )
    numAdults: Optional[
        Union[
            List[Union[int, "Integer", "QuantitativeValue", str]],
            int,
            "Integer",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The number of adults staying in the unit.",
    )
    checkinTime: Optional[
        Union[
            List[Union[datetime, "DateTime", time, "Time", str]],
            datetime,
            "DateTime",
            time,
            "Time",
            str,
        ]
    ] = Field(
        default=None,
        description="The earliest someone may check into a lodging establishment.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.QualitativeValue import QualitativeValue
    from pydantic2_schemaorg.Integer import Integer
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Time import Time



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.UKNonprofitType import UKNonprofitType


class CharitableIncorporatedOrganization(UKNonprofitType):
    """CharitableIncorporatedOrganization: Non-profit type referring to a Charitable Incorporated Organization
     (UK).

    See: https://schema.org/CharitableIncorporatedOrganization
    Model depth: 6
    """

    type_: str = Field(
        default="CharitableIncorporatedOrganization", alias="@type", const=True
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MediaManipulationRatingEnumeration import (
    MediaManipulationRatingEnumeration,
)


class DecontextualizedContent(MediaManipulationRatingEnumeration):
    """Content coded 'missing context' in a [[MediaReview]], considered in the context of how it was published or
     shared. For a [[VideoObject]] to be 'missing context': Presenting unaltered video in an inaccurate manner
     that misrepresents the footage. For example, using incorrect dates or locations, altering the transcript
     or sharing brief clips from a longer video to mislead viewers. (A video rated 'original' can also be missing
     context.) For an [[ImageObject]] to be 'missing context': Presenting unaltered images in an inaccurate
     manner to misrepresent the image and mislead the viewer. For example, a common tactic is using an unaltered
     image but saying it came from a different time or place. (An image rated 'original' can also be missing context.)
     For an [[ImageObject]] with embedded text to be 'missing context': An unaltered image presented in an inaccurate
     manner to misrepresent the image and mislead the viewer. For example, a common tactic is using an unaltered
     image but saying it came from a different time or place. (An 'original' image with inaccurate text would generally
     fall in this category.) For an [[AudioObject]] to be 'missing context': Unaltered audio presented in an inaccurate
     manner that misrepresents it. For example, using incorrect dates or locations, or sharing brief clips from
     a longer recording to mislead viewers. (Audio rated “original” can also be missing context.)

    See: https://schema.org/DecontextualizedContent
    Model depth: 5
    """

    type_: str = Field(default="DecontextualizedContent", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class Occupation(Intangible):
    """A profession, may involve prolonged training and/or a formal qualification.

    See: https://schema.org/Occupation
    Model depth: 3
    """

    type_: str = Field(default="Occupation", alias="@type", const=True)
    skills: Optional[
        Union[List[Union[str, "Text", "DefinedTerm"]], str, "Text", "DefinedTerm"]
    ] = Field(
        default=None,
        description="A statement of knowledge, skill, ability, task or any other assertion expressing a competency that is desired or required to fulfill this role or to work in this occupation.",
    )
    estimatedSalary: Optional[
        Union[
            List[
                Union[
                    StrictInt,
                    StrictFloat,
                    "Number",
                    "MonetaryAmount",
                    "MonetaryAmountDistribution",
                    str,
                ]
            ],
            StrictInt,
            StrictFloat,
            "Number",
            "MonetaryAmount",
            "MonetaryAmountDistribution",
            str,
        ]
    ] = Field(
        default=None,
        description="An estimated salary for a job posting or occupation, based on a variety of variables including, but not limited to industry, job title, and location. Estimated salaries are often computed by outside organizations rather than the hiring organization, who may not have committed to the estimated value.",
    )
    educationRequirements: Optional[
        Union[
            List[Union[str, "Text", "EducationalOccupationalCredential"]],
            str,
            "Text",
            "EducationalOccupationalCredential",
        ]
    ] = Field(
        default=None,
        description="Educational background needed for the position or Occupation.",
    )
    occupationalCategory: Optional[
        Union[List[Union[str, "Text", "CategoryCode"]], str, "Text", "CategoryCode"]
    ] = Field(
        default=None,
        description="A category describing the job, preferably using a term from a taxonomy such as [BLS O*NET-SOC](http://www.onetcenter.org/taxonomy.html), [ISCO-08](https://www.ilo.org/public/english/bureau/stat/isco/isco08/) or similar, with the property repeated for each applicable value. Ideally the taxonomy should be identified, and both the textual label and formal code for the category should be provided. Note: for historical reasons, any textual label and formal code provided as a literal may be assumed to be from O*NET-SOC.",
    )
    responsibilities: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Responsibilities associated with this role or Occupation.",
    )
    experienceRequirements: Optional[
        Union[
            List[Union[str, "Text", "OccupationalExperienceRequirements"]],
            str,
            "Text",
            "OccupationalExperienceRequirements",
        ]
    ] = Field(
        default=None,
        description="Description of skills and experience needed for the position or Occupation.",
    )
    occupationLocation: Optional[
        Union[List[Union["AdministrativeArea", str]], "AdministrativeArea", str]
    ] = Field(
        default=None,
        description="The region/country for which this occupational description is appropriate. Note that educational requirements and qualifications can vary between jurisdictions.",
    )
    qualifications: Optional[
        Union[
            List[Union[str, "Text", "EducationalOccupationalCredential"]],
            str,
            "Text",
            "EducationalOccupationalCredential",
        ]
    ] = Field(
        default=None,
        description="Specific qualifications required for this role or Occupation.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.DefinedTerm import DefinedTerm
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.MonetaryAmount import MonetaryAmount
    from pydantic2_schemaorg.MonetaryAmountDistribution import (
        MonetaryAmountDistribution,
    )
    from pydantic2_schemaorg.EducationalOccupationalCredential import (
        EducationalOccupationalCredential,
    )
    from pydantic2_schemaorg.CategoryCode import CategoryCode
    from pydantic2_schemaorg.OccupationalExperienceRequirements import (
        OccupationalExperienceRequirements,
    )
    from pydantic2_schemaorg.AdministrativeArea import AdministrativeArea



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from datetime import date


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalEntity import MedicalEntity


class MedicalGuideline(MedicalEntity):
    """Any recommendation made by a standard society (e.g. ACC/AHA) or consensus statement that denotes how to diagnose
     and treat a particular condition. Note: this type should be used to tag the actual guideline recommendation;
     if the guideline recommendation occurs in a larger scholarly article, use MedicalScholarlyArticle to tag
     the overall article, not this type. Note also: the organization making the recommendation should be captured
     in the recognizingAuthority base property of MedicalEntity.

    See: https://schema.org/MedicalGuideline
    Model depth: 3
    """

    type_: str = Field(default="MedicalGuideline", alias="@type", const=True)
    evidenceOrigin: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Source of the data used to formulate the guidance, e.g. RCT, consensus opinion, etc.",
    )
    guidelineDate: Optional[
        Union[List[Union[date, "Date", str]], date, "Date", str]
    ] = Field(
        default=None,
        description="Date on which this guideline's recommendation was made.",
    )
    guidelineSubject: Optional[
        Union[List[Union["MedicalEntity", str]], "MedicalEntity", str]
    ] = Field(
        default=None,
        description="The medical conditions, treatments, etc. that are the subject of the guideline.",
    )
    evidenceLevel: Optional[
        Union[List[Union["MedicalEvidenceLevel", str]], "MedicalEvidenceLevel", str]
    ] = Field(
        default=None,
        description="Strength of evidence of the data used to formulate the guideline (enumerated).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.MedicalEntity import MedicalEntity
    from pydantic2_schemaorg.MedicalEvidenceLevel import MedicalEvidenceLevel



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MusicReleaseFormatType import MusicReleaseFormatType


class DigitalFormat(MusicReleaseFormatType):
    """DigitalFormat.

    See: https://schema.org/DigitalFormat
    Model depth: 5
    """

    type_: str = Field(default="DigitalFormat", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Offer import Offer


class OfferForPurchase(Offer):
    """An [[OfferForPurchase]] in Schema.org represents an [[Offer]] to sell something, i.e. an [[Offer]] whose
     [[businessFunction]] is [sell](http://purl.org/goodrelations/v1#Sell.). See [Good Relations](https://en.wikipedia.org/wiki/GoodRelations)
     for background on the underlying concepts.

    See: https://schema.org/OfferForPurchase
    Model depth: 4
    """

    type_: str = Field(default="OfferForPurchase", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DrugPregnancyCategory import DrugPregnancyCategory


class FDAnotEvaluated(DrugPregnancyCategory):
    """A designation that the drug in question has not been assigned a pregnancy category designation by the US FDA.

    See: https://schema.org/FDAnotEvaluated
    Model depth: 6
    """

    type_: str = Field(default="FDAnotEvaluated", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSign import MedicalSign


class VitalSign(MedicalSign):
    """Vital signs are measures of various physiological functions in order to assess the most basic body functions.

    See: https://schema.org/VitalSign
    Model depth: 6
    """

    type_: str = Field(default="VitalSign", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalTest import MedicalTest


class ImagingTest(MedicalTest):
    """Any medical imaging modality typically used for diagnostic purposes.

    See: https://schema.org/ImagingTest
    Model depth: 4
    """

    type_: str = Field(default="ImagingTest", alias="@type", const=True)
    imagingTechnique: Optional[
        Union[
            List[Union["MedicalImagingTechnique", str]], "MedicalImagingTechnique", str
        ]
    ] = Field(
        default=None,
        description="Imaging technique used.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MedicalImagingTechnique import MedicalImagingTechnique



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MapCategoryType import MapCategoryType


class VenueMap(MapCategoryType):
    """A venue map (e.g. for malls, auditoriums, museums, etc.).

    See: https://schema.org/VenueMap
    Model depth: 5
    """

    type_: str = Field(default="VenueMap", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Product import Product


class IndividualProduct(Product):
    """A single, identifiable product instance (e.g. a laptop with a particular serial number).

    See: https://schema.org/IndividualProduct
    Model depth: 3
    """

    type_: str = Field(default="IndividualProduct", alias="@type", const=True)
    serialNumber: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The serial number or any alphanumeric identifier of a particular product. When attached to an offer, it is a shortcut for the serial number of the product included in the offer.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalEntity import MedicalEntity


class MedicalTest(MedicalEntity):
    """Any medical test, typically performed for diagnostic purposes.

    See: https://schema.org/MedicalTest
    Model depth: 3
    """

    type_: str = Field(default="MedicalTest", alias="@type", const=True)
    signDetected: Optional[
        Union[List[Union["MedicalSign", str]], "MedicalSign", str]
    ] = Field(
        default=None,
        description="A sign detected by the test.",
    )
    affectedBy: Optional[Union[List[Union["Drug", str]], "Drug", str]] = Field(
        default=None,
        description="Drugs that affect the test's results.",
    )
    usedToDiagnose: Optional[
        Union[List[Union["MedicalCondition", str]], "MedicalCondition", str]
    ] = Field(
        default=None,
        description="A condition the test is used to diagnose.",
    )
    normalRange: Optional[
        Union[
            List[Union[str, "Text", "MedicalEnumeration"]],
            str,
            "Text",
            "MedicalEnumeration",
        ]
    ] = Field(
        default=None,
        description="Range of acceptable values for a typical patient, when applicable.",
    )
    usesDevice: Optional[
        Union[List[Union["MedicalDevice", str]], "MedicalDevice", str]
    ] = Field(
        default=None,
        description="Device used to perform the test.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MedicalSign import MedicalSign
    from pydantic2_schemaorg.Drug import Drug
    from pydantic2_schemaorg.MedicalCondition import MedicalCondition
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.MedicalEnumeration import MedicalEnumeration
    from pydantic2_schemaorg.MedicalDevice import MedicalDevice



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ReturnLabelSourceEnumeration import (
    ReturnLabelSourceEnumeration,
)


class ReturnLabelInBox(ReturnLabelSourceEnumeration):
    """Specifies that a return label will be provided by the seller in the shipping box.

    See: https://schema.org/ReturnLabelInBox
    Model depth: 5
    """

    type_: str = Field(default="ReturnLabelInBox", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import StrictInt, StrictFloat
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.FinancialProduct import FinancialProduct


class InvestmentOrDeposit(FinancialProduct):
    """A type of financial product that typically requires the client to transfer funds to a financial service in
     return for potential beneficial financial return.

    See: https://schema.org/InvestmentOrDeposit
    Model depth: 5
    """

    type_: str = Field(default="InvestmentOrDeposit", alias="@type", const=True)
    amount: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "MonetaryAmount", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "MonetaryAmount",
            str,
        ]
    ] = Field(
        default=None,
        description="The amount of money.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.MonetaryAmount import MonetaryAmount



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.RefundTypeEnumeration import RefundTypeEnumeration


class StoreCreditRefund(RefundTypeEnumeration):
    """Specifies that the customer receives a store credit as refund when returning a product.

    See: https://schema.org/StoreCreditRefund
    Model depth: 5
    """

    type_: str = Field(default="StoreCreditRefund", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.GenderType import GenderType


class Male(GenderType):
    """The male gender.

    See: https://schema.org/Male
    Model depth: 5
    """

    type_: str = Field(default="Male", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalSpecialty import MedicalSpecialty


class SpeechPathology(MedicalSpecialty):
    """The scientific study and treatment of defects, disorders, and malfunctions of speech and voice, as stuttering,
     lisping, or lalling, and of language disturbances, as aphasia or delayed language acquisition.

    See: https://schema.org/SpeechPathology
    Model depth: 6
    """

    type_: str = Field(default="SpeechPathology", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.TransferAction import TransferAction


class GiveAction(TransferAction):
    """The act of transferring ownership of an object to a destination. Reciprocal of TakeAction. Related actions:
     * [[TakeAction]]: Reciprocal of GiveAction. * [[SendAction]]: Unlike SendAction, GiveAction implies
     that ownership is being transferred (e.g. I may send my laptop to you, but that doesn't mean I'm giving it to
     you).

    See: https://schema.org/GiveAction
    Model depth: 4
    """

    type_: str = Field(default="GiveAction", alias="@type", const=True)
    recipient: Optional[
        Union[
            List[Union["Organization", "Audience", "Person", "ContactPoint", str]],
            "Organization",
            "Audience",
            "Person",
            "ContactPoint",
            str,
        ]
    ] = Field(
        default=None,
        description="A sub property of participant. The participant who is at the receiving end of the action.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Audience import Audience
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.ContactPoint import ContactPoint



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Series import Series
from pydantic2_schemaorg.Event import Event


class EventSeries(Series, Event):
    """A series of [[Event]]s. Included events can relate with the series using the [[superEvent]] property. An
     EventSeries is a collection of events that share some unifying characteristic. For example, \"The Olympic
     Games\" is a series, which is repeated regularly. The \"2012 London Olympics\" can be presented both as an
     [[Event]] in the series \"Olympic Games\", and as an [[EventSeries]] that included a number of sporting competitions
     as Events. The nature of the association between the events in an [[EventSeries]] can vary, but typical examples
     could include a thematic event series (e.g. topical meetups or classes), or a series of regular events that
     share a location, attendee group and/or organizers. EventSeries has been defined as a kind of Event to make
     it easy for publishers to use it in an Event context without worrying about which kinds of series are really
     event-like enough to call an Event. In general an EventSeries may seem more Event-like when the period of time
     is compact and when aspects such as location are fixed, but it may also sometimes prove useful to describe a
     longer-term series as an Event.

    See: https://schema.org/EventSeries
    Model depth: 3
    """

    type_: str = Field(default="EventSeries", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.LearningResource import LearningResource


class Syllabus(LearningResource):
    """A syllabus that describes the material covered in a course, often with several such sections per [[Course]]
     so that a distinct [[timeRequired]] can be provided for that section of the [[Course]].

    See: https://schema.org/Syllabus
    Model depth: 4
    """

    type_: str = Field(default="Syllabus", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl, StrictBool, StrictInt, StrictFloat
from datetime import date, datetime


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class MerchantReturnPolicy(Intangible):
    """A MerchantReturnPolicy provides information about product return policies associated with an [[Organization]],
     [[Product]], or [[Offer]].

    See: https://schema.org/MerchantReturnPolicy
    Model depth: 3
    """

    type_: str = Field(default="MerchantReturnPolicy", alias="@type", const=True)
    returnPolicySeasonalOverride: Optional[
        Union[
            List[Union["MerchantReturnPolicySeasonalOverride", str]],
            "MerchantReturnPolicySeasonalOverride",
            str,
        ]
    ] = Field(
        default=None,
        description="Seasonal override of a return policy.",
    )
    returnPolicyCountry: Optional[
        Union[List[Union[str, "Text", "Country"]], str, "Text", "Country"]
    ] = Field(
        default=None,
        description='The country where the product has to be sent to for returns, for example "Ireland" using the [[name]] property of [[Country]]. You can also provide the two-letter [ISO 3166-1 alpha-2 country code](http://en.wikipedia.org/wiki/ISO_3166-1). Note that this can be different from the country where the product was originally shipped from or sent to.',
    )
    customerRemorseReturnLabelSource: Optional[
        Union[
            List[Union["ReturnLabelSourceEnumeration", str]],
            "ReturnLabelSourceEnumeration",
            str,
        ]
    ] = Field(
        default=None,
        description="The method (from an enumeration) by which the customer obtains a return shipping label for a product returned due to customer remorse.",
    )
    itemCondition: Optional[
        Union[List[Union["OfferItemCondition", str]], "OfferItemCondition", str]
    ] = Field(
        default=None,
        description="A predefined value from OfferItemCondition specifying the condition of the product or service, or the products or services included in the offer. Also used for product return policies to specify the condition of products accepted for returns.",
    )
    refundType: Optional[
        Union[List[Union["RefundTypeEnumeration", str]], "RefundTypeEnumeration", str]
    ] = Field(
        default=None,
        description="A refund type, from an enumerated list.",
    )
    inStoreReturnsOffered: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="Are in-store returns offered? (For more advanced return methods use the [[returnMethod]] property.)",
    )
    restockingFee: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "MonetaryAmount", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "MonetaryAmount",
            str,
        ]
    ] = Field(
        default=None,
        description="Use [[MonetaryAmount]] to specify a fixed restocking fee for product returns, or use [[Number]] to specify a percentage of the product price paid by the customer.",
    )
    merchantReturnDays: Optional[
        Union[
            List[Union[datetime, "DateTime", int, "Integer", date, "Date", str]],
            datetime,
            "DateTime",
            int,
            "Integer",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="Specifies either a fixed return date or the number of days (from the delivery date) that a product can be returned. Used when the [[returnPolicyCategory]] property is specified as [[MerchantReturnFiniteReturnWindow]].",
    )
    validForMemberTier: Optional[
        Union[List[Union["MemberProgramTier", str]], "MemberProgramTier", str]
    ] = Field(
        default=None,
        description="The membership program tier an Offer (or a PriceSpecification, OfferShippingDetails, or MerchantReturnPolicy under an Offer) is valid for.",
    )
    applicableCountry: Optional[
        Union[List[Union[str, "Text", "Country"]], str, "Text", "Country"]
    ] = Field(
        default=None,
        description="A country where a particular merchant return policy applies to, for example the two-letter ISO 3166-1 alpha-2 country code.",
    )
    customerRemorseReturnShippingFeesAmount: Optional[
        Union[List[Union["MonetaryAmount", str]], "MonetaryAmount", str]
    ] = Field(
        default=None,
        description="The amount of shipping costs if a product is returned due to customer remorse. Applicable when property [[customerRemorseReturnFees]] equals [[ReturnShippingFees]].",
    )
    returnFees: Optional[
        Union[List[Union["ReturnFeesEnumeration", str]], "ReturnFeesEnumeration", str]
    ] = Field(
        default=None,
        description="The type of return fees for purchased products (for any return reason).",
    )
    merchantReturnLink: Optional[
        Union[List[Union[AnyUrl, "URL", str]], AnyUrl, "URL", str]
    ] = Field(
        default=None,
        description="Specifies a Web page or service by URL, for product returns.",
    )
    returnShippingFeesAmount: Optional[
        Union[List[Union["MonetaryAmount", str]], "MonetaryAmount", str]
    ] = Field(
        default=None,
        description="Amount of shipping costs for product returns (for any reason). Applicable when property [[returnFees]] equals [[ReturnShippingFees]].",
    )
    additionalProperty: Optional[
        Union[List[Union["PropertyValue", str]], "PropertyValue", str]
    ] = Field(
        default=None,
        description="A property-value pair representing an additional characteristic of the entity, e.g. a product feature or another characteristic for which there is no matching property in schema.org. Note: Publishers should be aware that applications designed to use specific schema.org properties (e.g. https://schema.org/width, https://schema.org/color, https://schema.org/gtin13, ...) will typically expect such data to be provided using those properties, rather than using the generic property/value mechanism.",
    )
    customerRemorseReturnFees: Optional[
        Union[List[Union["ReturnFeesEnumeration", str]], "ReturnFeesEnumeration", str]
    ] = Field(
        default=None,
        description="The type of return fees if the product is returned due to customer remorse.",
    )
    itemDefectReturnLabelSource: Optional[
        Union[
            List[Union["ReturnLabelSourceEnumeration", str]],
            "ReturnLabelSourceEnumeration",
            str,
        ]
    ] = Field(
        default=None,
        description="The method (from an enumeration) by which the customer obtains a return shipping label for a defect product.",
    )
    itemDefectReturnFees: Optional[
        Union[List[Union["ReturnFeesEnumeration", str]], "ReturnFeesEnumeration", str]
    ] = Field(
        default=None,
        description="The type of return fees for returns of defect products.",
    )
    itemDefectReturnShippingFeesAmount: Optional[
        Union[List[Union["MonetaryAmount", str]], "MonetaryAmount", str]
    ] = Field(
        default=None,
        description="Amount of shipping costs for defect product returns. Applicable when property [[itemDefectReturnFees]] equals [[ReturnShippingFees]].",
    )
    returnMethod: Optional[
        Union[
            List[Union["ReturnMethodEnumeration", str]], "ReturnMethodEnumeration", str
        ]
    ] = Field(
        default=None,
        description="The type of return method offered, specified from an enumeration.",
    )
    returnPolicyCategory: Optional[
        Union[
            List[Union["MerchantReturnEnumeration", str]],
            "MerchantReturnEnumeration",
            str,
        ]
    ] = Field(
        default=None,
        description="Specifies an applicable return policy (from an enumeration).",
    )
    returnLabelSource: Optional[
        Union[
            List[Union["ReturnLabelSourceEnumeration", str]],
            "ReturnLabelSourceEnumeration",
            str,
        ]
    ] = Field(
        default=None,
        description="The method (from an enumeration) by which the customer obtains a return shipping label for a product returned for any reason.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MerchantReturnPolicySeasonalOverride import (
        MerchantReturnPolicySeasonalOverride,
    )
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.Country import Country
    from pydantic2_schemaorg.ReturnLabelSourceEnumeration import (
        ReturnLabelSourceEnumeration,
    )
    from pydantic2_schemaorg.OfferItemCondition import OfferItemCondition
    from pydantic2_schemaorg.RefundTypeEnumeration import RefundTypeEnumeration
    from pydantic2_schemaorg.Boolean import Boolean
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.MonetaryAmount import MonetaryAmount
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Integer import Integer
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.MemberProgramTier import MemberProgramTier
    from pydantic2_schemaorg.ReturnFeesEnumeration import ReturnFeesEnumeration
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.PropertyValue import PropertyValue
    from pydantic2_schemaorg.ReturnMethodEnumeration import ReturnMethodEnumeration
    from pydantic2_schemaorg.MerchantReturnEnumeration import MerchantReturnEnumeration



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.OnlineBusiness import OnlineBusiness


class OnlineStore(OnlineBusiness):
    """An eCommerce site.

    See: https://schema.org/OnlineStore
    Model depth: 4
    """

    type_: str = Field(default="OnlineStore", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.TransferAction import TransferAction


class DownloadAction(TransferAction):
    """The act of downloading an object.

    See: https://schema.org/DownloadAction
    Model depth: 4
    """

    type_: str = Field(default="DownloadAction", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.BioChemEntity import BioChemEntity


class ChemicalSubstance(BioChemEntity):
    """A chemical substance is 'a portion of matter of constant composition, composed of molecular entities of the
     same type or of different types' (source: [ChEBI:59999](https://www.ebi.ac.uk/chebi/searchId.do?chebiId=59999)).

    See: https://schema.org/ChemicalSubstance
    Model depth: 3
    """

    type_: str = Field(default="ChemicalSubstance", alias="@type", const=True)
    chemicalRole: Optional[
        Union[List[Union["DefinedTerm", str]], "DefinedTerm", str]
    ] = Field(
        default=None,
        description="A role played by the BioChemEntity within a chemical context.",
    )
    potentialUse: Optional[
        Union[List[Union["DefinedTerm", str]], "DefinedTerm", str]
    ] = Field(
        default=None,
        description="Intended use of the BioChemEntity by humans.",
    )
    chemicalComposition: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The chemical composition describes the identity and relative ratio of the chemical elements that make up the substance.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.DefinedTerm import DefinedTerm
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.PublicationIssue import PublicationIssue


class ComicIssue(PublicationIssue):
    """Individual comic issues are serially published as part of a larger series. For the sake of consistency, even
     one-shot issues belong to a series comprised of a single issue. All comic issues can be uniquely identified
     by: the combination of the name and volume number of the series to which the issue belongs; the issue number;
     and the variant description of the issue (if any).

    See: https://schema.org/ComicIssue
    Model depth: 4
    """

    type_: str = Field(default="ComicIssue", alias="@type", const=True)
    artist: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="The primary artist for a work in a medium other than pencils or digital line art--for example, if the primary artwork is done in watercolors or digital paints.",
    )
    inker: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="The individual who traces over the pencil drawings in ink after pencils are complete.",
    )
    letterer: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="The individual who adds lettering, including speech balloons and sound effects, to artwork.",
    )
    variantCover: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description='A description of the variant cover for the issue, if the issue is a variant printing. For example, "Bryan Hitch Variant Cover" or "2nd Printing Variant".',
    )
    colorist: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="The individual who adds color to inked drawings.",
    )
    penciler: Optional[Union[List[Union["Person", str]], "Person", str]] = Field(
        default=None,
        description="The individual who draws the primary narrative artwork.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Text import Text



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class StructuredValue(Intangible):
    """Structured values are used when the value of a property has a more complex structure than simply being a textual
     value or a reference to another thing.

    See: https://schema.org/StructuredValue
    Model depth: 3
    """

    type_: str = Field(default="StructuredValue", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.TradeAction import TradeAction


class SellAction(TradeAction):
    """The act of taking money from a buyer in exchange for goods or services rendered. An agent sells an object, product,
     or service to a buyer for a price. Reciprocal of BuyAction.

    See: https://schema.org/SellAction
    Model depth: 4
    """

    type_: str = Field(default="SellAction", alias="@type", const=True)
    warrantyPromise: Optional[
        Union[List[Union["WarrantyPromise", str]], "WarrantyPromise", str]
    ] = Field(
        default=None,
        description="The warranty promise(s) included in the offer.",
    )
    buyer: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="A sub property of participant. The participant/person/organization that bought the object.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.WarrantyPromise import WarrantyPromise
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalClinic import MedicalClinic


class CovidTestingFacility(MedicalClinic):
    """A CovidTestingFacility is a [[MedicalClinic]] where testing for the COVID-19 Coronavirus disease is available.
     If the facility is being made available from an established [[Pharmacy]], [[Hotel]], or other non-medical
     organization, multiple types can be listed. This makes it easier to re-use existing schema.org information
     about that place, e.g. contact info, address, opening hours. Note that in an emergency, such information
     may not always be reliable.

    See: https://schema.org/CovidTestingFacility
    Model depth: 5
    """

    type_: str = Field(default="CovidTestingFacility", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.AssessAction import AssessAction


class ReactAction(AssessAction):
    """The act of responding instinctively and emotionally to an object, expressing a sentiment.

    See: https://schema.org/ReactAction
    Model depth: 4
    """

    type_: str = Field(default="ReactAction", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import StrictBool
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Event import Event


class PublicationEvent(Event):
    """A PublicationEvent corresponds indifferently to the event of publication for a CreativeWork of any type,
     e.g. a broadcast event, an on-demand event, a book/journal publication via a variety of delivery media.

    See: https://schema.org/PublicationEvent
    Model depth: 3
    """

    type_: str = Field(default="PublicationEvent", alias="@type", const=True)
    free: Optional[
        Union[List[Union[StrictBool, "Boolean", str]], StrictBool, "Boolean", str]
    ] = Field(
        default=None,
        description="A flag to signal that the item, event, or place is accessible for free.",
    )
    publishedOn: Optional[
        Union[List[Union["BroadcastService", str]], "BroadcastService", str]
    ] = Field(
        default=None,
        description="A broadcast service associated with the publication event.",
    )
    publishedBy: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="An agent associated with the publication event.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Boolean import Boolean
    from pydantic2_schemaorg.BroadcastService import BroadcastService
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization



from __future__ import annotations
from typing import TYPE_CHECKING

from datetime import datetime, time
from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Reservation import Reservation


class FoodEstablishmentReservation(Reservation):
    """A reservation to dine at a food-related business. Note: This type is for information about actual reservations,
     e.g. in confirmation emails or HTML pages with individual confirmations of reservations.

    See: https://schema.org/FoodEstablishmentReservation
    Model depth: 4
    """

    type_: str = Field(
        default="FoodEstablishmentReservation", alias="@type", const=True
    )
    startTime: Optional[
        Union[
            List[Union[datetime, "DateTime", time, "Time", str]],
            datetime,
            "DateTime",
            time,
            "Time",
            str,
        ]
    ] = Field(
        default=None,
        description="The startTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to start. For actions that span a period of time, when the action was performed. E.g. John wrote a book from *January* to December. For media, including audio and video, it's the time offset of the start of a clip within a larger file. Note that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.",
    )
    endTime: Optional[
        Union[
            List[Union[datetime, "DateTime", time, "Time", str]],
            datetime,
            "DateTime",
            time,
            "Time",
            str,
        ]
    ] = Field(
        default=None,
        description="The endTime of something. For a reserved event or service (e.g. FoodEstablishmentReservation), the time that it is expected to end. For actions that span a period of time, when the action was performed. E.g. John wrote a book from January to *December*. For media, including audio and video, it's the time offset of the end of a clip within a larger file. Note that Event uses startDate/endDate instead of startTime/endTime, even when describing dates with times. This situation may be clarified in future revisions.",
    )
    partySize: Optional[
        Union[
            List[Union[int, "Integer", "QuantitativeValue", str]],
            int,
            "Integer",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="Number of people the reservation should accommodate.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Time import Time
    from pydantic2_schemaorg.Integer import Integer
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.Reservation import Reservation


class ReservationPackage(Reservation):
    """A group of multiple reservations with common values for all sub-reservations.

    See: https://schema.org/ReservationPackage
    Model depth: 4
    """

    type_: str = Field(default="ReservationPackage", alias="@type", const=True)
    subReservation: Optional[
        Union[List[Union["Reservation", str]], "Reservation", str]
    ] = Field(
        default=None,
        description="The individual reservations included in the package. Typically a repeated property.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Reservation import Reservation



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.USNonprofitType import USNonprofitType


class Nonprofit501c26(USNonprofitType):
    """Nonprofit501c26: Non-profit type referring to State-Sponsored Organizations Providing Health Coverage
     for High-Risk Individuals.

    See: https://schema.org/Nonprofit501c26
    Model depth: 6
    """

    type_: str = Field(default="Nonprofit501c26", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.LegalValueLevel import LegalValueLevel


class AuthoritativeLegalValue(LegalValueLevel):
    """Indicates that the publisher gives some special status to the publication of the document. (\"The Queens
     Printer\" version of a UK Act of Parliament, or the PDF version of a Directive published by the EU Office of Publications.)
     Something \"Authoritative\" is considered to be also [[OfficialLegalValue]].

    See: https://schema.org/AuthoritativeLegalValue
    Model depth: 5
    """

    type_: str = Field(default="AuthoritativeLegalValue", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from pydantic.v1 import StrictInt, StrictFloat
from typing import List, Optional, Union
from datetime import date, datetime


from pydantic.v1 import Field
from pydantic2_schemaorg.StructuredValue import StructuredValue


class CDCPMDRecord(StructuredValue):
    """A CDCPMDRecord is a data structure representing a record in a CDC tabular data format used for hospital data
     reporting. See [documentation](/docs/cdc-covid.html) for details, and the linked CDC materials for authoritative
     definitions used as the source here.

    See: https://schema.org/CDCPMDRecord
    Model depth: 4
    """

    type_: str = Field(default="CDCPMDRecord", alias="@type", const=True)
    cvdNumVentUse: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="numventuse - MECHANICAL VENTILATORS IN USE: Total number of ventilators in use.",
    )
    cvdNumICUBedsOcc: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="numicubedsocc - ICU BED OCCUPANCY: Total number of staffed inpatient ICU beds that are occupied.",
    )
    cvdNumC19OFMechVentPats: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="numc19ofmechventpats - ED/OVERFLOW and VENTILATED: Patients with suspected or confirmed COVID-19 who are in the ED or any overflow location awaiting an inpatient bed and on a mechanical ventilator.",
    )
    cvdNumC19Died: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="numc19died - DEATHS: Patients with suspected or confirmed COVID-19 who died in the hospital, ED, or any overflow location.",
    )
    cvdFacilityCounty: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Name of the County of the NHSN facility that this data record applies to. Use [[cvdFacilityId]] to identify the facility. To provide other details, [[healthcareReportingData]] can be used on a [[Hospital]] entry.",
    )
    cvdNumC19HospPats: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="numc19hosppats - HOSPITALIZED: Patients currently hospitalized in an inpatient care location who have suspected or confirmed COVID-19.",
    )
    datePosted: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="Publication date of an online listing.",
    )
    cvdFacilityId: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="Identifier of the NHSN facility that this data record applies to. Use [[cvdFacilityCounty]] to indicate the county. To provide other details, [[healthcareReportingData]] can be used on a [[Hospital]] entry.",
    )
    cvdNumBeds: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="numbeds - HOSPITAL INPATIENT BEDS: Inpatient beds, including all staffed, licensed, and overflow (surge) beds used for inpatients.",
    )
    cvdNumC19HOPats: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="numc19hopats - HOSPITAL ONSET: Patients hospitalized in an NHSN inpatient care location with onset of suspected or confirmed COVID-19 14 or more days after hospitalization.",
    )
    cvdNumICUBeds: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="numicubeds - ICU BEDS: Total number of staffed inpatient intensive care unit (ICU) beds.",
    )
    cvdNumTotBeds: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="numtotbeds - ALL HOSPITAL BEDS: Total number of all inpatient and outpatient beds, including all staffed, ICU, licensed, and overflow (surge) beds used for inpatients or outpatients.",
    )
    cvdNumVent: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="numvent - MECHANICAL VENTILATORS: Total number of ventilators available.",
    )
    cvdNumC19OverflowPats: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="numc19overflowpats - ED/OVERFLOW: Patients with suspected or confirmed COVID-19 who are in the ED or any overflow location awaiting an inpatient bed.",
    )
    cvdNumC19MechVentPats: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="numc19mechventpats - HOSPITALIZED and VENTILATED: Patients hospitalized in an NHSN inpatient care location who have suspected or confirmed COVID-19 and are on a mechanical ventilator.",
    )
    cvdNumBedsOcc: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="numbedsocc - HOSPITAL INPATIENT BED OCCUPANCY: Total number of staffed inpatient beds that are occupied.",
    )
    cvdCollectionDate: Optional[
        Union[
            List[Union[datetime, "DateTime", str, "Text"]],
            datetime,
            "DateTime",
            str,
            "Text",
        ]
    ] = Field(
        default=None,
        description="collectiondate - Date for which patient counts are reported.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Date import Date



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl
from datetime import datetime


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class Dataset(CreativeWork):
    """A body of structured information describing some topic(s) of interest.

    See: https://schema.org/Dataset
    Model depth: 3
    """

    type_: str = Field(default="Dataset", alias="@type", const=True)
    issn: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The International Standard Serial Number (ISSN) that identifies this serial publication. You can repeat this property to identify different formats of, or the linking ISSN (ISSN-L) for, this serial publication.",
    )
    catalog: Optional[Union[List[Union["DataCatalog", str]], "DataCatalog", str]] = (
        Field(
            default=None,
            description="A data catalog which contains this dataset.",
        )
    )
    measurementTechnique: Optional[
        Union[
            List[
                Union[
                    AnyUrl, "URL", str, "Text", "MeasurementMethodEnum", "DefinedTerm"
                ]
            ],
            AnyUrl,
            "URL",
            str,
            "Text",
            "MeasurementMethodEnum",
            "DefinedTerm",
        ]
    ] = Field(
        default=None,
        description='A technique, method or technology used in an [[Observation]], [[StatisticalVariable]] or [[Dataset]] (or [[DataDownload]], [[DataCatalog]]), corresponding to the method used for measuring the corresponding variable(s) (for datasets, described using [[variableMeasured]]; for [[Observation]], a [[StatisticalVariable]]). Often but not necessarily each [[variableMeasured]] will have an explicit representation as (or mapping to) an property such as those defined in Schema.org, or other RDF vocabularies and "knowledge graphs". In that case the subproperty of [[variableMeasured]] called [[measuredProperty]] is applicable. The [[measurementTechnique]] property helps when extra clarification is needed about how a [[measuredProperty]] was measured. This is oriented towards scientific and scholarly dataset publication but may have broader applicability; it is not intended as a full representation of measurement, but can often serve as a high level summary for dataset discovery. For example, if [[variableMeasured]] is: molecule concentration, [[measurementTechnique]] could be: "mass spectrometry" or "nmr spectroscopy" or "colorimetry" or "immunofluorescence". If the [[variableMeasured]] is "depression rating", the [[measurementTechnique]] could be "Zung Scale" or "HAM-D" or "Beck Depression Inventory". If there are several [[variableMeasured]] properties recorded for some given data object, use a [[PropertyValue]] for each [[variableMeasured]] and attach the corresponding [[measurementTechnique]]. The value can also be from an enumeration, organized as a [[MeasurementMetholdEnumeration]].',
    )
    distribution: Optional[
        Union[List[Union["DataDownload", str]], "DataDownload", str]
    ] = Field(
        default=None,
        description="A downloadable form of this dataset, at a specific location, in a specific format. This property can be repeated if different variations are available. There is no expectation that different downloadable distributions must contain exactly equivalent information (see also [DCAT](https://www.w3.org/TR/vocab-dcat-3/#Class:Distribution) on this point). Different distributions might include or exclude different subsets of the entire dataset, for example.",
    )
    variableMeasured: Optional[
        Union[
            List[
                Union[str, "Text", "Property", "StatisticalVariable", "PropertyValue"]
            ],
            str,
            "Text",
            "Property",
            "StatisticalVariable",
            "PropertyValue",
        ]
    ] = Field(
        default=None,
        description="The variableMeasured property can indicate (repeated as necessary) the variables that are measured in some dataset, either described as text or as pairs of identifier and description using PropertyValue, or more explicitly as a [[StatisticalVariable]].",
    )
    includedDataCatalog: Optional[
        Union[List[Union["DataCatalog", str]], "DataCatalog", str]
    ] = Field(
        default=None,
        description="A data catalog which contains this dataset (this property was previously 'catalog', preferred name is now 'includedInDataCatalog').",
    )
    datasetTimeInterval: Optional[
        Union[List[Union[datetime, "DateTime", str]], datetime, "DateTime", str]
    ] = Field(
        default=None,
        description="The range of temporal applicability of a dataset, e.g. for a 2011 census dataset, the year 2011 (in ISO 8601 time interval format).",
    )
    measurementMethod: Optional[
        Union[
            List[
                Union[
                    AnyUrl, "URL", str, "Text", "MeasurementMethodEnum", "DefinedTerm"
                ]
            ],
            AnyUrl,
            "URL",
            str,
            "Text",
            "MeasurementMethodEnum",
            "DefinedTerm",
        ]
    ] = Field(
        default=None,
        description="A subproperty of [[measurementTechnique]] that can be used for specifying specific methods, in particular via [[MeasurementMethodEnum]].",
    )
    includedInDataCatalog: Optional[
        Union[List[Union["DataCatalog", str]], "DataCatalog", str]
    ] = Field(
        default=None,
        description="A data catalog which contains this dataset.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.DataCatalog import DataCatalog
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.MeasurementMethodEnum import MeasurementMethodEnum
    from pydantic2_schemaorg.DefinedTerm import DefinedTerm
    from pydantic2_schemaorg.DataDownload import DataDownload
    from pydantic2_schemaorg.Property import Property
    from pydantic2_schemaorg.StatisticalVariable import StatisticalVariable
    from pydantic2_schemaorg.PropertyValue import PropertyValue
    from pydantic2_schemaorg.DateTime import DateTime



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class MusicRecording(CreativeWork):
    """A music recording (track), usually a single song.

    See: https://schema.org/MusicRecording
    Model depth: 3
    """

    type_: str = Field(default="MusicRecording", alias="@type", const=True)
    duration: Optional[Union[List[Union["Duration", str]], "Duration", str]] = Field(
        default=None,
        description="The duration of the item (movie, audio recording, event, etc.) in [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601).",
    )
    byArtist: Optional[
        Union[List[Union["Person", "MusicGroup", str]], "Person", "MusicGroup", str]
    ] = Field(
        default=None,
        description="The artist that performed this album or recording.",
    )
    isrcCode: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The International Standard Recording Code for the recording.",
    )
    recordingOf: Optional[
        Union[List[Union["MusicComposition", str]], "MusicComposition", str]
    ] = Field(
        default=None,
        description="The composition this track is a recording of.",
    )
    inPlaylist: Optional[
        Union[List[Union["MusicPlaylist", str]], "MusicPlaylist", str]
    ] = Field(
        default=None,
        description="The playlist to which this recording belongs.",
    )
    inAlbum: Optional[Union[List[Union["MusicAlbum", str]], "MusicAlbum", str]] = Field(
        default=None,
        description="The album to which this recording belongs.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Duration import Duration
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.MusicGroup import MusicGroup
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.MusicComposition import MusicComposition
    from pydantic2_schemaorg.MusicPlaylist import MusicPlaylist
    from pydantic2_schemaorg.MusicAlbum import MusicAlbum



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.USNonprofitType import USNonprofitType


class Nonprofit501c8(USNonprofitType):
    """Nonprofit501c8: Non-profit type referring to Fraternal Beneficiary Societies and Associations.

    See: https://schema.org/Nonprofit501c8
    Model depth: 6
    """

    type_: str = Field(default="Nonprofit501c8", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ActionStatusType import ActionStatusType


class ActiveActionStatus(ActionStatusType):
    """An in-progress action (e.g., while watching the movie, or driving to a location).

    See: https://schema.org/ActiveActionStatus
    Model depth: 6
    """

    type_: str = Field(default="ActiveActionStatus", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DataType import DataType


class Text(DataType):
    """Data type: Text.

    See: https://schema.org/Text
    Model depth: 5
    """

    type_: str = Field(default="Text", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.AssessAction import AssessAction


class IgnoreAction(AssessAction):
    """The act of intentionally disregarding the object. An agent ignores an object.

    See: https://schema.org/IgnoreAction
    Model depth: 4
    """

    type_: str = Field(default="IgnoreAction", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class MediaReviewItem(CreativeWork):
    """Represents an item or group of closely related items treated as a unit for the sake of evaluation in a [[MediaReview]].
     Authorship etc. apply to the items rather than to the curation/grouping or reviewing party.

    See: https://schema.org/MediaReviewItem
    Model depth: 3
    """

    type_: str = Field(default="MediaReviewItem", alias="@type", const=True)
    mediaItemAppearance: Optional[
        Union[List[Union["MediaObject", str]], "MediaObject", str]
    ] = Field(
        default=None,
        description="In the context of a [[MediaReview]], indicates specific media item(s) that are grouped using a [[MediaReviewItem]].",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.MediaObject import MediaObject



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class BroadcastFrequencySpecification(Intangible):
    """The frequency in MHz and the modulation used for a particular BroadcastService.

    See: https://schema.org/BroadcastFrequencySpecification
    Model depth: 3
    """

    type_: str = Field(
        default="BroadcastFrequencySpecification", alias="@type", const=True
    )
    broadcastSignalModulation: Optional[
        Union[
            List[Union[str, "Text", "QualitativeValue"]],
            str,
            "Text",
            "QualitativeValue",
        ]
    ] = Field(
        default=None,
        description="The modulation (e.g. FM, AM, etc) used by a particular broadcast service.",
    )
    broadcastSubChannel: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The subchannel used for the broadcast.",
    )
    broadcastFrequencyValue: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "QuantitativeValue", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The frequency in MHz for a particular broadcast.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.QualitativeValue import QualitativeValue
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ContactPointOption import ContactPointOption


class HearingImpairedSupported(ContactPointOption):
    """Uses devices to support users with hearing impairments.

    See: https://schema.org/HearingImpairedSupported
    Model depth: 5
    """

    type_: str = Field(default="HearingImpairedSupported", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CreativeWork import CreativeWork


class Sculpture(CreativeWork):
    """A piece of sculpture.

    See: https://schema.org/Sculpture
    Model depth: 3
    """

    type_: str = Field(default="Sculpture", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.EntertainmentBusiness import EntertainmentBusiness


class ComedyClub(EntertainmentBusiness):
    """A comedy club.

    See: https://schema.org/ComedyClub
    Model depth: 5
    """

    type_: str = Field(default="ComedyClub", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.GamePlayMode import GamePlayMode


class MultiPlayer(GamePlayMode):
    """Play mode: MultiPlayer. Requiring or allowing multiple human players to play simultaneously.

    See: https://schema.org/MultiPlayer
    Model depth: 5
    """

    type_: str = Field(default="MultiPlayer", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.EducationalOccupationalProgram import (
    EducationalOccupationalProgram,
)


class WorkBasedProgram(EducationalOccupationalProgram):
    """A program with both an educational and employment component. Typically based at a workplace and structured
     around work-based learning, with the aim of instilling competencies related to an occupation. WorkBasedProgram
     is used to distinguish programs such as apprenticeships from school, college or other classroom based educational
     programs.

    See: https://schema.org/WorkBasedProgram
    Model depth: 4
    """

    type_: str = Field(default="WorkBasedProgram", alias="@type", const=True)
    occupationalCategory: Optional[
        Union[List[Union[str, "Text", "CategoryCode"]], str, "Text", "CategoryCode"]
    ] = Field(
        default=None,
        description="A category describing the job, preferably using a term from a taxonomy such as [BLS O*NET-SOC](http://www.onetcenter.org/taxonomy.html), [ISCO-08](https://www.ilo.org/public/english/bureau/stat/isco/isco08/) or similar, with the property repeated for each applicable value. Ideally the taxonomy should be identified, and both the textual label and formal code for the category should be provided. Note: for historical reasons, any textual label and formal code provided as a literal may be assumed to be from O*NET-SOC.",
    )
    trainingSalary: Optional[
        Union[
            List[Union["MonetaryAmountDistribution", str]],
            "MonetaryAmountDistribution",
            str,
        ]
    ] = Field(
        default=None,
        description="The estimated salary earned while in the program.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.CategoryCode import CategoryCode
    from pydantic2_schemaorg.MonetaryAmountDistribution import (
        MonetaryAmountDistribution,
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Enumeration import Enumeration


class ReturnLabelSourceEnumeration(Enumeration):
    """Enumerates several types of return labels for product returns.

    See: https://schema.org/ReturnLabelSourceEnumeration
    Model depth: 4
    """

    type_: str = Field(
        default="ReturnLabelSourceEnumeration", alias="@type", const=True
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MerchantReturnEnumeration import MerchantReturnEnumeration


class MerchantReturnFiniteReturnWindow(MerchantReturnEnumeration):
    """Specifies that there is a finite window for product returns.

    See: https://schema.org/MerchantReturnFiniteReturnWindow
    Model depth: 5
    """

    type_: str = Field(
        default="MerchantReturnFiniteReturnWindow", alias="@type", const=True
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.AdministrativeArea import AdministrativeArea


class City(AdministrativeArea):
    """A city or town.

    See: https://schema.org/City
    Model depth: 4
    """

    type_: str = Field(default="City", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.DigitalDocumentPermissionType import (
    DigitalDocumentPermissionType,
)


class WritePermission(DigitalDocumentPermissionType):
    """Permission to write or edit the document.

    See: https://schema.org/WritePermission
    Model depth: 5
    """

    type_: str = Field(default="WritePermission", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Organization import Organization


class ResearchOrganization(Organization):
    """A Research Organization (e.g. scientific institute, research company).

    See: https://schema.org/ResearchOrganization
    Model depth: 3
    """

    type_: str = Field(default="ResearchOrganization", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.GamePlayMode import GamePlayMode


class CoOp(GamePlayMode):
    """Play mode: CoOp. Co-operative games, where you play on the same team with friends.

    See: https://schema.org/CoOp
    Model depth: 5
    """

    type_: str = Field(default="CoOp", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.SportsActivityLocation import SportsActivityLocation


class TennisComplex(SportsActivityLocation):
    """A tennis complex.

    See: https://schema.org/TennisComplex
    Model depth: 5
    """

    type_: str = Field(default="TennisComplex", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.BodyMeasurementTypeEnumeration import (
    BodyMeasurementTypeEnumeration,
)


class BodyMeasurementNeck(BodyMeasurementTypeEnumeration):
    """Girth of neck. Used, for example, to fit shirts.

    See: https://schema.org/BodyMeasurementNeck
    Model depth: 6
    """

    type_: str = Field(default="BodyMeasurementNeck", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from datetime import date, datetime
from pydantic.v1 import AnyUrl, StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class EducationalOccupationalProgram(Intangible):
    """A program offered by an institution which determines the learning progress to achieve an outcome, usually
     a credential like a degree or certificate. This would define a discrete set of opportunities (e.g., job, courses)
     that together constitute a program with a clear start, end, set of requirements, and transition to a new occupational
     opportunity (e.g., a job), or sometimes a higher educational opportunity (e.g., an advanced degree).

    See: https://schema.org/EducationalOccupationalProgram
    Model depth: 3
    """

    type_: str = Field(
        default="EducationalOccupationalProgram", alias="@type", const=True
    )
    programPrerequisites: Optional[
        Union[
            List[
                Union[
                    str,
                    "Text",
                    "EducationalOccupationalCredential",
                    "Course",
                    "AlignmentObject",
                ]
            ],
            str,
            "Text",
            "EducationalOccupationalCredential",
            "Course",
            "AlignmentObject",
        ]
    ] = Field(
        default=None,
        description="Prerequisites for enrolling in the program.",
    )
    endDate: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The end date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601)).",
    )
    occupationalCategory: Optional[
        Union[List[Union[str, "Text", "CategoryCode"]], str, "Text", "CategoryCode"]
    ] = Field(
        default=None,
        description="A category describing the job, preferably using a term from a taxonomy such as [BLS O*NET-SOC](http://www.onetcenter.org/taxonomy.html), [ISCO-08](https://www.ilo.org/public/english/bureau/stat/isco/isco08/) or similar, with the property repeated for each applicable value. Ideally the taxonomy should be identified, and both the textual label and formal code for the category should be provided. Note: for historical reasons, any textual label and formal code provided as a literal may be assumed to be from O*NET-SOC.",
    )
    numberOfCredits: Optional[
        Union[
            List[Union[int, "Integer", "StructuredValue", str]],
            int,
            "Integer",
            "StructuredValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The number of credits or units awarded by a Course or required to complete an EducationalOccupationalProgram.",
    )
    termsPerYear: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="The number of times terms of study are offered per year. Semesters and quarters are common units for term. For example, if the student can only take 2 semesters for the program in one year, then termsPerYear should be 2.",
    )
    maximumEnrollment: Optional[
        Union[List[Union[int, "Integer", str]], int, "Integer", str]
    ] = Field(
        default=None,
        description="The maximum number of students who may be enrolled in the program.",
    )
    dayOfWeek: Optional[Union[List[Union["DayOfWeek", str]], "DayOfWeek", str]] = Field(
        default=None,
        description="The day of the week for which these opening hours are valid.",
    )
    educationalProgramMode: Optional[
        Union[List[Union[AnyUrl, "URL", str, "Text"]], AnyUrl, "URL", str, "Text"]
    ] = Field(
        default=None,
        description='Similar to courseMode, the medium or means of delivery of the program as a whole. The value may either be a text label (e.g. "online", "onsite" or "blended"; "synchronous" or "asynchronous"; "full-time" or "part-time") or a URL reference to a term from a controlled vocabulary (e.g. https://ceds.ed.gov/element/001311#Asynchronous ).',
    )
    typicalCreditsPerTerm: Optional[
        Union[
            List[Union[int, "Integer", "StructuredValue", str]],
            int,
            "Integer",
            "StructuredValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The number of credits or units a full-time student would be expected to take in 1 term however 'term' is defined by the institution.",
    )
    termDuration: Optional[Union[List[Union["Duration", str]], "Duration", str]] = (
        Field(
            default=None,
            description="The amount of time in a term as defined by the institution. A term is a length of time where students take one or more classes. Semesters and quarters are common units for term.",
        )
    )
    financialAidEligible: Optional[
        Union[List[Union[str, "Text", "DefinedTerm"]], str, "Text", "DefinedTerm"]
    ] = Field(
        default=None,
        description="A financial aid type or program which students may use to pay for tuition or fees associated with the program.",
    )
    timeToComplete: Optional[Union[List[Union["Duration", str]], "Duration", str]] = (
        Field(
            default=None,
            description="The expected length of time to complete the program if attending full-time.",
        )
    )
    salaryUponCompletion: Optional[
        Union[
            List[Union["MonetaryAmountDistribution", str]],
            "MonetaryAmountDistribution",
            str,
        ]
    ] = Field(
        default=None,
        description="The expected salary upon completing the training.",
    )
    trainingSalary: Optional[
        Union[
            List[Union["MonetaryAmountDistribution", str]],
            "MonetaryAmountDistribution",
            str,
        ]
    ] = Field(
        default=None,
        description="The estimated salary earned while in the program.",
    )
    applicationDeadline: Optional[
        Union[List[Union[date, "Date", str]], date, "Date", str]
    ] = Field(
        default=None,
        description="The date at which the program stops collecting applications for the next enrollment cycle.",
    )
    provider: Optional[
        Union[List[Union["Person", "Organization", str]], "Person", "Organization", str]
    ] = Field(
        default=None,
        description="The service provider, service operator, or service performer; the goods producer. Another party (a seller) may offer those services or goods on behalf of the provider. A provider may also serve as the seller.",
    )
    hasCourse: Optional[Union[List[Union["Course", str]], "Course", str]] = Field(
        default=None,
        description="A course or class that is one of the learning opportunities that constitute an educational / occupational program. No information is implied about whether the course is mandatory or optional; no guarantee is implied about whether the course will be available to everyone on the program.",
    )
    programType: Optional[
        Union[List[Union[str, "Text", "DefinedTerm"]], str, "Text", "DefinedTerm"]
    ] = Field(
        default=None,
        description="The type of educational or occupational program. For example, classroom, internship, alternance, etc.",
    )
    occupationalCredentialAwarded: Optional[
        Union[
            List[
                Union[AnyUrl, "URL", str, "Text", "EducationalOccupationalCredential"]
            ],
            AnyUrl,
            "URL",
            str,
            "Text",
            "EducationalOccupationalCredential",
        ]
    ] = Field(
        default=None,
        description="A description of the qualification, award, certificate, diploma or other occupational credential awarded as a consequence of successful completion of this course or program.",
    )
    offers: Optional[
        Union[List[Union["Demand", "Offer", str]], "Demand", "Offer", str]
    ] = Field(
        default=None,
        description="An offer to provide this item&#x2014;for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event. Use [[businessFunction]] to indicate the kind of transaction offered, i.e. sell, lease, etc. This property can also be used to describe a [[Demand]]. While this property is listed as expected on a number of common types, it can be used in others. In that case, using a second type, such as Product or a subtype of Product, can clarify the nature of the offer.",
    )
    timeOfDay: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description='The time of day the program normally runs. For example, "evenings".',
    )
    startDate: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The start date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601)).",
    )
    educationalCredentialAwarded: Optional[
        Union[
            List[
                Union[AnyUrl, "URL", str, "Text", "EducationalOccupationalCredential"]
            ],
            AnyUrl,
            "URL",
            str,
            "Text",
            "EducationalOccupationalCredential",
        ]
    ] = Field(
        default=None,
        description="A description of the qualification, award, certificate, diploma or other educational credential awarded as a consequence of successful completion of this course or program.",
    )
    applicationStartDate: Optional[
        Union[List[Union[date, "Date", str]], date, "Date", str]
    ] = Field(
        default=None,
        description="The date at which the program begins collecting applications for the next enrollment cycle.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.EducationalOccupationalCredential import (
        EducationalOccupationalCredential,
    )
    from pydantic2_schemaorg.Course import Course
    from pydantic2_schemaorg.AlignmentObject import AlignmentObject
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.CategoryCode import CategoryCode
    from pydantic2_schemaorg.Integer import Integer
    from pydantic2_schemaorg.StructuredValue import StructuredValue
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.DayOfWeek import DayOfWeek
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.Duration import Duration
    from pydantic2_schemaorg.DefinedTerm import DefinedTerm
    from pydantic2_schemaorg.MonetaryAmountDistribution import (
        MonetaryAmountDistribution,
    )
    from pydantic2_schemaorg.Person import Person
    from pydantic2_schemaorg.Organization import Organization
    from pydantic2_schemaorg.Demand import Demand
    from pydantic2_schemaorg.Offer import Offer



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.AnatomicalStructure import AnatomicalStructure


class BrainStructure(AnatomicalStructure):
    """Any anatomical structure which pertains to the soft nervous tissue functioning as the coordinating center
     of sensation and intellectual and nervous activity.

    See: https://schema.org/BrainStructure
    Model depth: 4
    """

    type_: str = Field(default="BrainStructure", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class AlignmentObject(Intangible):
    """An intangible item that describes an alignment between a learning resource and a node in an educational framework.
     Should not be used where the nature of the alignment can be described using a simple property, for example to
     express that a resource [[teaches]] or [[assesses]] a competency.

    See: https://schema.org/AlignmentObject
    Model depth: 3
    """

    type_: str = Field(default="AlignmentObject", alias="@type", const=True)
    targetDescription: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The description of a node in an established educational framework.",
    )
    targetName: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The name of a node in an established educational framework.",
    )
    educationalFramework: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = (
        Field(
            default=None,
            description="The framework to which the resource being described is aligned.",
        )
    )
    targetUrl: Optional[Union[List[Union[AnyUrl, "URL", str]], AnyUrl, "URL", str]] = (
        Field(
            default=None,
            description="The URL of a node in an established educational framework.",
        )
    )
    alignmentType: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="A category of alignment between the learning resource and the framework node. Recommended values include: 'requires', 'textComplexity', 'readingLevel', and 'educationalSubject'.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.URL import URL



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.CreateAction import CreateAction


class DrawAction(CreateAction):
    """The act of producing a visual/graphical representation of an object, typically with a pen/pencil and paper
     as instruments.

    See: https://schema.org/DrawAction
    Model depth: 4
    """

    type_: str = Field(default="DrawAction", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.ItemListOrderType import ItemListOrderType


class ItemListOrderDescending(ItemListOrderType):
    """An ItemList ordered with higher values listed first.

    See: https://schema.org/ItemListOrderDescending
    Model depth: 5
    """

    type_: str = Field(default="ItemListOrderDescending", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.RestrictedDiet import RestrictedDiet


class HalalDiet(RestrictedDiet):
    """A diet conforming to Islamic dietary practices.

    See: https://schema.org/HalalDiet
    Model depth: 5
    """

    type_: str = Field(default="HalalDiet", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.HealthAndBeautyBusiness import HealthAndBeautyBusiness


class NailSalon(HealthAndBeautyBusiness):
    """A nail salon.

    See: https://schema.org/NailSalon
    Model depth: 5
    """

    type_: str = Field(default="NailSalon", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalEntity import MedicalEntity


class MedicalContraindication(MedicalEntity):
    """A condition or factor that serves as a reason to withhold a certain medical therapy. Contraindications can
     be absolute (there are no reasonable circumstances for undertaking a course of action) or relative (the patient
     is at higher risk of complications, but these risks may be outweighed by other considerations or mitigated
     by other measures).

    See: https://schema.org/MedicalContraindication
    Model depth: 3
    """

    type_: str = Field(default="MedicalContraindication", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.Review import Review


class CriticReview(Review):
    """A [[CriticReview]] is a more specialized form of Review written or published by a source that is recognized
     for its reviewing activities. These can include online columns, travel and food guides, TV and radio shows,
     blogs and other independent Web sites. [[CriticReview]]s are typically more in-depth and professionally
     written. For simpler, casually written user/visitor/viewer/customer reviews, it is more appropriate
     to use the [[UserReview]] type. Review aggregator sites such as Metacritic already separate out the site's
     user reviews from selected critic reviews that originate from third-party sources.

    See: https://schema.org/CriticReview
    Model depth: 4
    """

    type_: str = Field(default="CriticReview", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MedicalTest import MedicalTest


class BloodTest(MedicalTest):
    """A medical test performed on a sample of a patient's blood.

    See: https://schema.org/BloodTest
    Model depth: 4
    """

    type_: str = Field(default="BloodTest", alias="@type", const=True)



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.BroadcastChannel import BroadcastChannel


class RadioChannel(BroadcastChannel):
    """A unique instance of a radio BroadcastService on a CableOrSatelliteService lineup.

    See: https://schema.org/RadioChannel
    Model depth: 4
    """

    type_: str = Field(default="RadioChannel", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from datetime import date, datetime
from typing import List, Optional, Union
from pydantic.v1 import StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class MerchantReturnPolicySeasonalOverride(Intangible):
    """A seasonal override of a return policy, for example used for holidays.

    See: https://schema.org/MerchantReturnPolicySeasonalOverride
    Model depth: 3
    """

    type_: str = Field(
        default="MerchantReturnPolicySeasonalOverride", alias="@type", const=True
    )
    endDate: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The end date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601)).",
    )
    refundType: Optional[
        Union[List[Union["RefundTypeEnumeration", str]], "RefundTypeEnumeration", str]
    ] = Field(
        default=None,
        description="A refund type, from an enumerated list.",
    )
    restockingFee: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "MonetaryAmount", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "MonetaryAmount",
            str,
        ]
    ] = Field(
        default=None,
        description="Use [[MonetaryAmount]] to specify a fixed restocking fee for product returns, or use [[Number]] to specify a percentage of the product price paid by the customer.",
    )
    merchantReturnDays: Optional[
        Union[
            List[Union[datetime, "DateTime", int, "Integer", date, "Date", str]],
            datetime,
            "DateTime",
            int,
            "Integer",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="Specifies either a fixed return date or the number of days (from the delivery date) that a product can be returned. Used when the [[returnPolicyCategory]] property is specified as [[MerchantReturnFiniteReturnWindow]].",
    )
    returnFees: Optional[
        Union[List[Union["ReturnFeesEnumeration", str]], "ReturnFeesEnumeration", str]
    ] = Field(
        default=None,
        description="The type of return fees for purchased products (for any return reason).",
    )
    returnShippingFeesAmount: Optional[
        Union[List[Union["MonetaryAmount", str]], "MonetaryAmount", str]
    ] = Field(
        default=None,
        description="Amount of shipping costs for product returns (for any reason). Applicable when property [[returnFees]] equals [[ReturnShippingFees]].",
    )
    startDate: Optional[
        Union[
            List[Union[datetime, "DateTime", date, "Date", str]],
            datetime,
            "DateTime",
            date,
            "Date",
            str,
        ]
    ] = Field(
        default=None,
        description="The start date and time of the item (in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601)).",
    )
    returnMethod: Optional[
        Union[
            List[Union["ReturnMethodEnumeration", str]], "ReturnMethodEnumeration", str
        ]
    ] = Field(
        default=None,
        description="The type of return method offered, specified from an enumeration.",
    )
    returnPolicyCategory: Optional[
        Union[
            List[Union["MerchantReturnEnumeration", str]],
            "MerchantReturnEnumeration",
            str,
        ]
    ] = Field(
        default=None,
        description="Specifies an applicable return policy (from an enumeration).",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.DateTime import DateTime
    from pydantic2_schemaorg.Date import Date
    from pydantic2_schemaorg.RefundTypeEnumeration import RefundTypeEnumeration
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.MonetaryAmount import MonetaryAmount
    from pydantic2_schemaorg.Integer import Integer
    from pydantic2_schemaorg.ReturnFeesEnumeration import ReturnFeesEnumeration
    from pydantic2_schemaorg.ReturnMethodEnumeration import ReturnMethodEnumeration
    from pydantic2_schemaorg.MerchantReturnEnumeration import MerchantReturnEnumeration



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class EntryPoint(Intangible):
    """An entry point, within some Web-based protocol.

    See: https://schema.org/EntryPoint
    Model depth: 3
    """

    type_: str = Field(default="EntryPoint", alias="@type", const=True)
    contentType: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The supported content type(s) for an EntryPoint response.",
    )
    actionPlatform: Optional[
        Union[
            List[Union[AnyUrl, "URL", str, "Text", "DigitalPlatformEnumeration"]],
            AnyUrl,
            "URL",
            str,
            "Text",
            "DigitalPlatformEnumeration",
        ]
    ] = Field(
        default=None,
        description="The high level platform(s) where the Action can be performed for the given URL. To specify a specific application or operating system instance, use actionApplication.",
    )
    application: Optional[
        Union[List[Union["SoftwareApplication", str]], "SoftwareApplication", str]
    ] = Field(
        default=None,
        description="An application that can complete the request.",
    )
    httpMethod: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="An HTTP method that specifies the appropriate HTTP method for a request to an HTTP EntryPoint. Values are capitalized strings as used in HTTP.",
    )
    encodingType: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The supported encoding type(s) for an EntryPoint request.",
    )
    urlTemplate: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="An url template (RFC6570) that will be used to construct the target of the execution of the action.",
    )
    actionApplication: Optional[
        Union[List[Union["SoftwareApplication", str]], "SoftwareApplication", str]
    ] = Field(
        default=None,
        description="An application that can complete the request.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.DigitalPlatformEnumeration import (
        DigitalPlatformEnumeration,
    )
    from pydantic2_schemaorg.SoftwareApplication import SoftwareApplication



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.TradeAction import TradeAction


class QuoteAction(TradeAction):
    """An agent quotes/estimates/appraises an object/product/service with a price at a location/store.

    See: https://schema.org/QuoteAction
    Model depth: 4
    """

    type_: str = Field(default="QuoteAction", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.AnatomicalStructure import AnatomicalStructure


class Muscle(AnatomicalStructure):
    """A muscle is an anatomical structure consisting of a contractile form of tissue that animals use to effect movement.

    See: https://schema.org/Muscle
    Model depth: 4
    """

    type_: str = Field(default="Muscle", alias="@type", const=True)
    muscleAction: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = Field(
        default=None,
        description="The movement the muscle generates.",
    )
    insertion: Optional[
        Union[List[Union["AnatomicalStructure", str]], "AnatomicalStructure", str]
    ] = Field(
        default=None,
        description="The place of attachment of a muscle, or what the muscle moves.",
    )
    nerve: Optional[Union[List[Union["Nerve", str]], "Nerve", str]] = Field(
        default=None,
        description="The underlying innervation associated with the muscle.",
    )
    bloodSupply: Optional[Union[List[Union["Vessel", str]], "Vessel", str]] = Field(
        default=None,
        description="The blood vessel that carries blood from the heart to the muscle.",
    )
    antagonist: Optional[Union[List[Union["Muscle", str]], "Muscle", str]] = Field(
        default=None,
        description="The muscle whose action counteracts the specified muscle.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.AnatomicalStructure import AnatomicalStructure
    from pydantic2_schemaorg.Nerve import Nerve
    from pydantic2_schemaorg.Vessel import Vessel



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.AdultOrientedEnumeration import AdultOrientedEnumeration


class UnclassifiedAdultConsideration(AdultOrientedEnumeration):
    """The item is suitable only for adults, without indicating why. Due to widespread use of \"adult\" as a euphemism
     for \"sexual\", many such items are likely suited also for the SexualContentConsideration code.

    See: https://schema.org/UnclassifiedAdultConsideration
    Model depth: 5
    """

    type_: str = Field(
        default="UnclassifiedAdultConsideration", alias="@type", const=True
    )



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.PaymentMethodType import PaymentMethodType


class ByInvoice(PaymentMethodType):
    """Payment by invoice, typically after the goods were delivered, equivalent to <code>http://purl.org/goodrelations/v1#ByInvoice</code>.

    See: https://schema.org/ByInvoice
    Model depth: 5
    """

    type_: str = Field(default="ByInvoice", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.BioChemEntity import BioChemEntity


class Gene(BioChemEntity):
    """A discrete unit of inheritance which affects one or more biological traits (Source: [https://en.wikipedia.org/wiki/Gene](https://en.wikipedia.org/wiki/Gene)).
     Examples include FOXP2 (Forkhead box protein P2), SCARNA21 (small Cajal body-specific RNA 21), A- (agouti
     genotype).

    See: https://schema.org/Gene
    Model depth: 3
    """

    type_: str = Field(default="Gene", alias="@type", const=True)
    alternativeOf: Optional[Union[List[Union["Gene", str]], "Gene", str]] = Field(
        default=None,
        description="Another gene which is a variation of this one.",
    )
    encodesBioChemEntity: Optional[
        Union[List[Union["BioChemEntity", str]], "BioChemEntity", str]
    ] = Field(
        default=None,
        description="Another BioChemEntity encoded by this one.",
    )
    hasBioPolymerSequence: Optional[Union[List[Union[str, "Text"]], str, "Text"]] = (
        Field(
            default=None,
            description="A symbolic representation of a BioChemEntity. For example, a nucleotide sequence of a Gene or an amino acid sequence of a Protein.",
        )
    )
    expressedIn: Optional[
        Union[
            List[
                Union[
                    "AnatomicalSystem",
                    "AnatomicalStructure",
                    "DefinedTerm",
                    "BioChemEntity",
                    str,
                ]
            ],
            "AnatomicalSystem",
            "AnatomicalStructure",
            "DefinedTerm",
            "BioChemEntity",
            str,
        ]
    ] = Field(
        default=None,
        description="Tissue, organ, biological sample, etc in which activity of this gene has been observed experimentally. For example brain, digestive system.",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.BioChemEntity import BioChemEntity
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.AnatomicalSystem import AnatomicalSystem
    from pydantic2_schemaorg.AnatomicalStructure import AnatomicalStructure
    from pydantic2_schemaorg.DefinedTerm import DefinedTerm



from __future__ import annotations


from pydantic.v1 import Field
from pydantic2_schemaorg.MediaManipulationRatingEnumeration import (
    MediaManipulationRatingEnumeration,
)


class SatireOrParodyContent(MediaManipulationRatingEnumeration):
    """Content coded 'satire or parody content' in a [[MediaReview]], considered in the context of how it was published
     or shared. For a [[VideoObject]] to be 'satire or parody content': A video that was created as political or
     humorous commentary and is presented in that context. (Reshares of satire/parody content that do not include
     relevant context are more likely to fall under the “missing context” rating.) For an [[ImageObject]] to be
     'satire or parody content': An image that was created as political or humorous commentary and is presented
     in that context. (Reshares of satire/parody content that do not include relevant context are more likely
     to fall under the “missing context” rating.) For an [[ImageObject]] with embedded text to be 'satire or parody
     content': An image that was created as political or humorous commentary and is presented in that context.
     (Reshares of satire/parody content that do not include relevant context are more likely to fall under the
     “missing context” rating.) For an [[AudioObject]] to be 'satire or parody content': Audio that was created
     as political or humorous commentary and is presented in that context. (Reshares of satire/parody content
     that do not include relevant context are more likely to fall under the “missing context” rating.)

    See: https://schema.org/SatireOrParodyContent
    Model depth: 5
    """

    type_: str = Field(default="SatireOrParodyContent", alias="@type", const=True)



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union
from pydantic.v1 import AnyUrl, StrictBool, StrictInt, StrictFloat


from pydantic.v1 import Field
from pydantic2_schemaorg.Intangible import Intangible


class FloorPlan(Intangible):
    """A FloorPlan is an explicit representation of a collection of similar accommodations, allowing the provision
     of common information (room counts, sizes, layout diagrams) and offers for rental or sale. In typical use,
     some [[ApartmentComplex]] has an [[accommodationFloorPlan]] which is a [[FloorPlan]]. A FloorPlan is
     always in the context of a particular place, either a larger [[ApartmentComplex]] or a single [[Apartment]].
     The visual/spatial aspects of a floor plan (i.e. room layout, [see wikipedia](https://en.wikipedia.org/wiki/Floor_plan))
     can be indicated using [[image]].

    See: https://schema.org/FloorPlan
    Model depth: 3
    """

    type_: str = Field(default="FloorPlan", alias="@type", const=True)
    isPlanForApartment: Optional[
        Union[List[Union["Accommodation", str]], "Accommodation", str]
    ] = Field(
        default=None,
        description="Indicates some accommodation that this floor plan describes.",
    )
    numberOfBedrooms: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "QuantitativeValue", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The total integer number of bedrooms in a some [[Accommodation]], [[ApartmentComplex]] or [[FloorPlan]].",
    )
    floorSize: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="The size of the accommodation, e.g. in square meter or squarefoot. Typical unit code(s): MTK for square meter, FTK for square foot, or YDK for square yard.",
    )
    petsAllowed: Optional[
        Union[
            List[Union[StrictBool, "Boolean", str, "Text"]],
            StrictBool,
            "Boolean",
            str,
            "Text",
        ]
    ] = Field(
        default=None,
        description="Indicates whether pets are allowed to enter the accommodation or lodging business. More detailed information can be put in a text value.",
    )
    numberOfAvailableAccommodationUnits: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="Indicates the number of available accommodation units in an [[ApartmentComplex]], or the number of accommodation units for a specific [[FloorPlan]] (within its specific [[ApartmentComplex]]). See also [[numberOfAccommodationUnits]].",
    )
    layoutImage: Optional[
        Union[
            List[Union[AnyUrl, "URL", "ImageObject", str]],
            AnyUrl,
            "URL",
            "ImageObject",
            str,
        ]
    ] = Field(
        default=None,
        description="A schematic image showing the floorplan layout.",
    )
    numberOfAccommodationUnits: Optional[
        Union[List[Union["QuantitativeValue", str]], "QuantitativeValue", str]
    ] = Field(
        default=None,
        description="Indicates the total (available plus unavailable) number of accommodation units in an [[ApartmentComplex]], or the number of accommodation units for a specific [[FloorPlan]] (within its specific [[ApartmentComplex]]). See also [[numberOfAvailableAccommodationUnits]].",
    )
    numberOfFullBathrooms: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="Number of full bathrooms - The total number of full and ¾ bathrooms in an [[Accommodation]]. This corresponds to the [BathroomsFull field in RESO](https://ddwiki.reso.org/display/DDW17/BathroomsFull+Field).",
    )
    numberOfPartialBathrooms: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", str]],
            StrictInt,
            StrictFloat,
            "Number",
            str,
        ]
    ] = Field(
        default=None,
        description="Number of partial bathrooms - The total number of half and ¼ bathrooms in an [[Accommodation]]. This corresponds to the [BathroomsPartial field in RESO](https://ddwiki.reso.org/display/DDW17/BathroomsPartial+Field).",
    )
    amenityFeature: Optional[
        Union[
            List[Union["LocationFeatureSpecification", str]],
            "LocationFeatureSpecification",
            str,
        ]
    ] = Field(
        default=None,
        description="An amenity feature (e.g. a characteristic or service) of the Accommodation. This generic property does not make a statement about whether the feature is included in an offer for the main accommodation or available at extra costs.",
    )
    numberOfRooms: Optional[
        Union[
            List[Union[StrictInt, StrictFloat, "Number", "QuantitativeValue", str]],
            StrictInt,
            StrictFloat,
            "Number",
            "QuantitativeValue",
            str,
        ]
    ] = Field(
        default=None,
        description="The number of rooms (excluding bathrooms and closets) of the accommodation or lodging business. Typical unit code(s): ROM for room or C62 for no unit. The type of room can be put in the unitText property of the QuantitativeValue.",
    )
    numberOfBathroomsTotal: Optional[
        Union[List[Union[int, "Integer", str]], int, "Integer", str]
    ] = Field(
        default=None,
        description='The total integer number of bathrooms in some [[Accommodation]], following real estate conventions as [documented in RESO](https://ddwiki.reso.org/display/DDW17/BathroomsTotalInteger+Field): "The simple sum of the number of bathrooms. For example for a property with two Full Bathrooms and one Half Bathroom, the Bathrooms Total Integer will be 3.". See also [[numberOfRooms]].',
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.Accommodation import Accommodation
    from pydantic2_schemaorg.Number import Number
    from pydantic2_schemaorg.QuantitativeValue import QuantitativeValue
    from pydantic2_schemaorg.Boolean import Boolean
    from pydantic2_schemaorg.Text import Text
    from pydantic2_schemaorg.URL import URL
    from pydantic2_schemaorg.ImageObject import ImageObject
    from pydantic2_schemaorg.LocationFeatureSpecification import (
        LocationFeatureSpecification,
    )
    from pydantic2_schemaorg.Integer import Integer



from __future__ import annotations
from typing import TYPE_CHECKING

from typing import List, Optional, Union


from pydantic.v1 import Field
from pydantic2_schemaorg.LocalBusiness import LocalBusiness


class ArchiveOrganization(LocalBusiness):
    """An organization with archival holdings. An organization which keeps and preserves archival material and
     typically makes it accessible to the public.

    See: https://schema.org/ArchiveOrganization
    Model depth: 4
    """

    type_: str = Field(default="ArchiveOrganization", alias="@type", const=True)
    archiveHeld: Optional[
        Union[List[Union["ArchiveComponent", str]], "ArchiveComponent", str]
    ] = Field(
        default=None,
        description="Collection, [fonds](https://en.wikipedia.org/wiki/Fonds), or item held, kept or maintained by an [[ArchiveOrganization]].",
    )


if TYPE_CHECKING:
    from pydantic2_schemaorg.ArchiveComponent import ArchiveComponent
